@@ -13,12 +13,15 @@
 #include "libkita/favoritethreads.h"
 #include "libkita/kita_misc.h"
 #include "libkita/threadinfo.h"
+#include "libkita/signalcollection.h"
+#include "libkita/parsemisc.h"
 
 #include <qmap.h>
 #include <qapplication.h>
 #include <qclipboard.h>
 #include <qdatetime.h>
 #include <qtoolbutton.h>
+#include <qlabel.h>
 
 #include <klocale.h>
 #include <kpopupmenu.h>
@@ -31,12 +34,22 @@ FavoriteListView::FavoriteListView( QWidget* parent, const char* name )
 {
     subjectList->addColumn( i18n( "Board" ) );
 
-    ReloadButton->hide();
+    KindLabel->hide();
 
-    connect( subjectList, SIGNAL( clicked( QListViewItem* ) ),
+    Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
+    connect( subjectList, SIGNAL( returnPressed( QListViewItem* ) ),
              SLOT( loadThread( QListViewItem* ) ) );
     connect( subjectList, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
              SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
+    connect( ReloadButton, SIGNAL( clicked() ),
+             SLOT( slotReloadButton() ) );
+    connect( this, SIGNAL( openBoardRequested( const QString&, bool ) ),
+             signalCollection, SIGNAL( openBoardRequested( const QString&, bool ) ) );
+    connect( signalCollection, SIGNAL( favoritesUpdated() ),
+             SLOT( update() ) );
+
+    connect( signalCollection, SIGNAL( updateSubjectTab( const KURL& ) ),
+             SLOT( slotUpdateSubject( const KURL& ) ) );  
 }
 
 FavoriteListView::~FavoriteListView()
@@ -93,15 +106,17 @@ void FavoriteListView::loadThread( QListViewItem* item )
         const Kita::Thread* thread = Kita::Thread::getByURL( *it );
 
         if ( thread->datURL() == item->text( Col_DatURL ) ) {
-            emit showThreadRequested( thread, false );
+            emit showThreadRequested( thread->datURL(), false );
         }
     }
 }
 
-void FavoriteListView::updateThread( const Kita::Thread* updated_thread )
+void FavoriteListView::slotUpdateSubject( const KURL& url )
 {
+    KURL datURL = Kita::ParseMisc::parseURLonly( url );
+    Kita::Thread* updated_thread = Kita::Thread::getByURLNew( datURL );
     for ( QListViewItem * item = subjectList->firstChild(); item; item = item->nextSibling() ) {
-        if ( item->text( Col_DatURL ) == updated_thread->datURL() ) {
+        if ( item->text( Col_DatURL ) == datURL.prettyURL() ) {
             int resNum = updated_thread->resNum();
             int readNum = KitaThreadInfo::readNum( updated_thread->datURL() );
             item->setText( Col_ResNum, QString( "%1" ).arg( resNum, 4 ) );
@@ -121,6 +136,7 @@ void FavoriteListView::slotContextMenuRequested( QListViewItem* item, const QPoi
     popup.insertItem( i18n( "Open with Web Browser" ), 0 );
     popup.insertItem( i18n( "Open with new tab" ), 1 );
     popup.insertItem( i18n( "Copy title and URL" ), 2 );
+    popup.insertItem( i18n( "Remove from Favorites" ), 3 );
 
     Kita::Thread* thread = Kita::Thread::getByURL( item->text( Col_DatURL ) );
 
@@ -131,12 +147,37 @@ void FavoriteListView::slotContextMenuRequested( QListViewItem* item, const QPoi
         KRun::runURL( thread->url(), "text/html" );
         break;
     case 1:
-        emit showThreadRequested( thread, true );
+        emit showThreadRequested( thread->datURL(), true );
         break;
     case 2:
         clipboard->setText( thread->name() + "\n" + thread->url() );
         break;
+    case 3:
+        emit bookmarked( thread->datURL(), false );
+        break;
     default:
         break;
     }
 }
+
+void FavoriteListView::slotReloadButton()
+{
+    QValueList<QString> boardList;
+    
+    const QValueList<QString> threadList = FavoriteThreads::getInstance() -> threadList();
+    QValueList<QString>::const_iterator it;
+    for ( it = threadList.begin(); it != threadList.end(); ++it ) {
+        const Kita::Thread* thread = Kita::Thread::getByURL( *it );
+        QString boardURL = Kita::datToBoard( thread->datURL() );
+        if ( boardList.contains( boardURL ) == 0 ) {
+            boardList.append( boardURL );
+        }
+    }
+
+    QValueList<QString>::const_iterator it2;
+    for ( it2 = boardList.begin(); it2 != boardList.end(); ++it2 ) {
+        // Ĥsubject.txt
+        Kita::Board::getThreadList( (*it2 ) );
+    }
+}
+
