@@ -17,14 +17,18 @@
 #include "libkita/favoriteboards.h"
 #include "kitathreadtabwidget.h"
 #include "kitasubjecttabwidget.h"
+#include "kitanavi.h"
 
-#include "libkita/thread.h"
 #include "libkita/favoritethreads.h"
 #include "libkita/kita_misc.h"
+#include "libkita/kitaconfig.h"
+#include "libkita/signalcollection.h"
+#include "libkita/parsemisc.h"
 
 #include <qdragobject.h>
 #include <qtextcodec.h>
 #include <qevent.h>
+#include <qregexp.h>
 
 #include <klineedit.h>
 #include <kglobal.h>
@@ -35,6 +39,7 @@
 #include <kkeydialog.h>
 #include <kaccel.h>
 #include <kio/netaccess.h>
+#include <kuserprofile.h>
 #include <kfiledialog.h>
 #include <kconfig.h>
 #include <kurl.h>
@@ -46,9 +51,12 @@
 #include <kstdaccel.h>
 #include <kaction.h>
 #include <kstdaction.h>
+#include <kshortcut.h>
+#include <kaboutdata.h>
+#include <kparts/partmanager.h>
 
 KitaMainWindow::KitaMainWindow()
-        : KDockMainWindow( 0, "Kita" ),
+        : KParts::DockMainWindow( 0, "Kita" ),
         m_printer( 0 )
 {
     // accept dnd
@@ -75,6 +83,11 @@ KitaMainWindow::KitaMainWindow()
     // load ascii art
     loadAsciiArt();
 
+    // load abone lists
+    loadAboneIDList();
+    loadAboneNameList();
+    loadAboneWordList();
+
     // and a status bar
     statusBar() ->show();
 
@@ -88,39 +101,48 @@ KitaMainWindow::KitaMainWindow()
     setAutoSaveSettings();
 
     // allow the view to change the statusbar and caption
-    connect( m_threadTab, SIGNAL( signalChangeStatusbar( const QString& ) ),
-             SLOT( changeStatusbar( const QString& ) ) );
+    Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
+    connect( signalCollection, SIGNAL( setMainCaption( const QString& ) ),
+             SLOT( slotSetMainCaption( const QString& ) ) );
 
-    connect( m_boardView, SIGNAL( openBoardRequested( const QString&, bool ) ),
-             m_subjectTab, SLOT( loadBoard( const QString&, bool ) ) );
+    connect( signalCollection, SIGNAL( setMainStatusbar( const QString& ) ),
+             SLOT( slotSetMainStatusbar( const QString& ) ) );
 
-    connect( m_subjectTab, SIGNAL( showThreadRequested( const Kita::Thread*, bool ) ),
-             m_threadTab, SLOT( showThread( const Kita::Thread*, bool ) ) );
+    connect( signalCollection, SIGNAL( setMainURLLine( const KURL& ) ),
+             SLOT( setUrl( const KURL& ) ) );
 
-    connect( m_threadTab, SIGNAL( thread( const Kita::Thread* ) ),
-             m_subjectTab, SLOT( updateThread( const Kita::Thread* ) ) );
+    connect( signalCollection, SIGNAL( switchSubjectView() ),
+             SLOT( slotSwitchSubjectView() ));
 
-    connect( m_threadTab, SIGNAL( thread( const Kita::Thread* ) ),
-             SLOT( slotThread( const Kita::Thread* ) ) );
+    connect( this, SIGNAL( switchSubjectView() ),
+	     signalCollection, SIGNAL( switchSubjectView() ));
+    
+    connect( m_subjectTab, SIGNAL( showThreadRequested( const QString&, bool ) ),
+             SLOT( switchThreadView( const QString&, bool ) ) );
 
-    connect( m_threadTab, SIGNAL( writeSucceeded() ),
+    connect( m_subjectTab, SIGNAL( showThreadRequested( const QString&, bool ) ),
+             m_threadTab, SLOT( showThread( const QString&, bool ) ) );
+
+    connect( signalCollection, SIGNAL( writeSucceeded() ),
              SLOT( slotWriteSucceeded() ) );
 
-    connect( m_threadTab, SIGNAL( showThreadCompleted( const KURL& ) ),
-             SLOT( setUrl( const KURL& ) ) );
+    connect( m_threadTab->manager(), SIGNAL( activePartChanged( KParts::Part* ) ),
+             SLOT( createGUI( KParts::Part* ) ) );
 
     connect( m_subjectTab, SIGNAL( loadBoardCompleted( const KURL& ) ),
              SLOT( setUrl( const KURL& ) ) );
 
-    connect( m_threadTab, SIGNAL( bookmarked( const Kita::Thread*, bool ) ),
-             SLOT( bookmark( const Kita::Thread*, bool ) ) );
+    connect( signalCollection, SIGNAL( bookmarked( const QString&, bool ) ),
+             SLOT( bookmark( const QString&, bool ) ) );
 
     connect( m_urlLine, SIGNAL( returnPressed() ),
-             SLOT( slotUrlLine() ) );
+             SLOT( slotURLLine() ) );
 
-    QPopupMenu* popup = static_cast<QPopupMenu *>( factory() ->container( "window", this ) );
-    connect( popup, SIGNAL( aboutToShow() ),
-             SLOT( windowMenuAboutToShow() ) );
+    connect( this, SIGNAL( favoritesUpdated() ),
+             signalCollection, SIGNAL( favoritesUpdated() ) );
+    //QPopupMenu* popup = static_cast<QPopupMenu *>( factory() ->container( "window", this ) );
+    //connect( popup, SIGNAL( aboutToShow() ),
+    //         SLOT( windowMenuAboutToShow() ) );
 
     QPopupMenu* settingsPopup = static_cast<QPopupMenu *>( factory() ->container( "settings", this ) );
     connect( settingsPopup, SIGNAL( aboutToShow() ),
@@ -128,10 +150,19 @@ KitaMainWindow::KitaMainWindow()
 
     m_boardView->loadBoardList();
     m_boardView->setFocus();
+    m_boardListAction->activate();
+    m_subjectListAction->activate(); // dummy code
 }
 
 KitaMainWindow::~KitaMainWindow()
 {
+    if ( ! m_subjectListAction->isChecked() )
+        makeDockVisible( m_subjectDock );
+
+    saveAboneIDList();
+    saveAboneNameList();
+    saveAboneWordList();
+
     saveAsciiArt();
 
     saveCompletion();
@@ -158,7 +189,8 @@ void KitaMainWindow::load( const KURL& url )
 
 #if 0
     // download the contents
-    if ( KIO::NetAccess::download( url, target ) ) {
+    if ( KIO::NetAccess::download( url, target ) )
+    {
         // set our caption
         setCaption( url );
 
@@ -176,10 +208,8 @@ void KitaMainWindow::load( const KURL& url )
 
 void KitaMainWindow::setupActions()
 {
-    KStdAction::openNew( this, SLOT( fileNew() ), actionCollection() );
     KStdAction::quit( this, SLOT( close() ), actionCollection() );
     KStdAction::copy( this, SLOT( slotEditCopy() ), actionCollection() );
-    KStdAction::find( m_threadTab, SLOT( focusSearchCombo() ), actionCollection() );
 
     m_toolbarAction = KStdAction::showToolbar( this,
                       SLOT( optionsShowToolbar() ),
@@ -203,19 +233,12 @@ void KitaMainWindow::setupActions()
                           actionCollection(),
                           "window_show_subject_list" );
 
-    m_showAddressAction = new KToggleAction( i18n( "Show mail address field" ),
-                          0,
-                          this,
-                          SLOT( settingsShowMailAddress() ),
-                          actionCollection(),
-                          "settings_show_mail_address" );
-
     m_urlLine = new KLineEdit( "", 0 );
     new KWidgetAction( m_urlLine,
                        i18n( "URL Line" ),
                        0,
                        this,
-                       SLOT( slotUrlLine() )        /* dummy */,
+                       SLOT( slotURLLine() )         /* dummy */,
                        actionCollection(), "url_line_action" );
 
     KStdAction::keyBindings( this, SLOT( optionsConfigureKeys() ), actionCollection() );
@@ -229,20 +252,6 @@ void KitaMainWindow::setupActions()
                  actionCollection(),
                  "load_board_list" );
 
-    new KAction( i18n( "Reload" ),
-                 KStdAccel::reload(),
-                 m_threadTab,
-                 SLOT( reloadThread() ),
-                 actionCollection(),
-                 "reload" );
-
-    new KAction( i18n( "Close Current Thread Tab" ),
-                 KStdAccel::close(),
-                 this,
-                 SLOT( windowCloseTab() ),
-                 actionCollection(),
-                 "close_tab" );
-
     new KAction( i18n( "reset windows" ),
                  0,
                  this,
@@ -250,14 +259,38 @@ void KitaMainWindow::setupActions()
                  actionCollection(),
                  "reset_win" );
 
-    createGUI();
+    m_toggleViewAction = new KAction(
+                             i18n( "&Toggle subject view and thread view" ),
+                             KShortcut(Qt::Key_F7),
+                             this,
+                             SLOT( windowToggleView() ),
+                             actionCollection(),
+                             "window_toggle_view" );
+
+    // action for subjecttabwidget
+    new KAction( i18n( "Close Current Thread Tab" ),
+                 KStdAccel::close(),
+                 m_threadTab,
+                 SLOT( closeCurrentTab() ),
+                 actionCollection(),
+                 "threadtab_closetab" );
+    new KAction( i18n( "&Reload subject list"),
+                 KShortcut(Qt::CTRL | Qt::Key_F5),
+                 m_subjectTab,
+                 SLOT( reloadSubjectList() ),
+                 actionCollection(),
+                 "threadlist_reload" );
+
+    m_threadTab->manager()->addManagedTopLevelWidget( m_mainDock );
+    setXMLFile( "kitaui.rc" );
+    createGUI( m_threadTab->manager()->activePart() );
 }
 
-void KitaMainWindow::slotUrlLine()
+void KitaMainWindow::slotURLLine()
 {
     QString text = m_urlLine->text();
     QString datURL = Kita::threadToDat( text );
-    m_threadTab->showThread( datURL );
+    m_threadTab->showThread( datURL, KitaConfig::alwaysUseTab() );
 }
 
 void KitaMainWindow::writeConfig( KConfig* config )
@@ -266,6 +299,14 @@ void KitaMainWindow::writeConfig( KConfig* config )
     config->writeEntry( "Font", KitaConfig::font() );
     config->writeEntry( "ThreadFont", KitaConfig::threadFont() );
     config->writeEntry( "ShowMailAddress", KitaConfig::showMailAddress() );
+    config->writeEntry( "MarkTime", KitaConfig::MarkTime() );
+    config->writeEntry( "SortOrder", KitaConfig::sortOrder() );
+    config->writeEntry( "AlwaysUseTab", KitaConfig::alwaysUseTab() );
+    config->writeEntry( "ShowAA", KitaConfig::showAA() );
+    config->writeEntry( "AfterShowNum", KitaConfig::afterShowNum() );
+    config->writeEntry( "PreShowNum", KitaConfig::preShowNum() );
+    config->writeEntry( "UsePart", KitaConfig::usePart() );
+    config->writeEntry( "PartMimeList", KitaConfig::partMimeList() );
 
     config->setGroup( "Color" );
     config->writeEntry( "Popup", KitaConfig::popupColor() );
@@ -289,18 +330,36 @@ void KitaMainWindow::readConfig( KConfig* config )
     KitaConfig::setFont( config->readFontEntry( "Font" ) );
     KitaConfig::setThreadFont( config->readFontEntry( "ThreadFont" ) );
     KitaConfig::setShowMailAddresss( config->readBoolEntry( "ShowMailAddress" ) );
+    KitaConfig::setMarkTime( config->readUnsignedNumEntry( "MarkTime" , 24 ) );
+    KitaConfig::setViewMode( config->readNumEntry( "ViewMode", KitaConfig::View_2pane ) );
+    KitaConfig::setSortOrder( config->readNumEntry( "SortOrder", KitaConfig::Order_Mark ) );
+    KitaConfig::setAlwaysUseTab( config->readBoolEntry( "AlwaysUseTab", false ) );
+    KitaConfig::setShowAA( config->readBoolEntry( "ShowAA", false ) );
+    KitaConfig::setAfterShowNum( config->readNumEntry( "AfterShowNum", 100 ) );
+    KitaConfig::setPreShowNum( config->readNumEntry( "PreShowNum", 50 ) );
+    KitaConfig::setUsePart( config->readBoolEntry( "UsePart", true ) );
+    if ( config->hasKey( "PartMimeList" ) )
+        KitaConfig::setPartMimeList( config->readListEntry( "PartMimeList" ) );
+    else {
+        // set partMimeList default
+        QStringList list;
+        list << "image/gif" << "image/jpeg" << "image/png" << "image/x-bmp";
+        KitaConfig::setPartMimeList( list );
+    }
 
     setFont( KitaConfig::font() );
 
     config->setGroup( "Color" );
 
     QColor popupColor = config->readColorEntry( "Popup" );
-    if ( popupColor.isValid() ) {
+    if ( popupColor.isValid() )
+    {
         KitaConfig::setPopupColor( popupColor );
     }
 
     QColor popupBackgroundColor = config->readColorEntry( "PopupBackground" );
-    if ( popupColor.isValid() ) {
+    if ( popupColor.isValid() )
+    {
         KitaConfig::setPopupBackgroundColor( popupBackgroundColor );
     }
 }
@@ -333,7 +392,8 @@ void KitaMainWindow::dropEvent( QDropEvent* event )
     QStrList uri;
 
     // see if we can decode a URI.. if not, just ignore it
-    if ( QUriDrag::decode( event, uri ) ) {
+    if ( QUriDrag::decode( event, uri ) )
+    {
         // okay, we have a URI.. process it
         QString url, target;
         url = uri.first();
@@ -357,9 +417,12 @@ void KitaMainWindow::optionsShowToolbar()
 {
     // this is all very cut and paste code for showing/hiding the
     // toolbar
-    if ( m_toolbarAction->isChecked() ) {
+    if ( m_toolbarAction->isChecked() )
+    {
         toolBar() ->show();
-    } else {
+    }
+    else
+    {
         toolBar() ->hide();
     }
 }
@@ -368,22 +431,32 @@ void KitaMainWindow::optionsShowStatusbar()
 {
     // this is all very cut and paste code for showing/hiding the
     // statusbar
-    if ( m_statusbarAction->isChecked() ) {
+    if ( m_statusbarAction->isChecked() )
+    {
         statusBar() ->show();
-    } else {
+    }
+    else
+    {
         statusBar() ->hide();
     }
 }
 
 void KitaMainWindow::optionsConfigureKeys()
 {
-    KKeyDialog::configureKeys( actionCollection(), "kitaui.rc" );
+    KKeyDialog dlg( TRUE, this);
+    QPtrList<KXMLGUIClient> actList = guiFactory()->clients();
+    for ( QPtrListIterator<KXMLGUIClient> act( actList ) ; act.current() ; ++act )
+    {
+        const KAboutData *dat = (*act)->instance()->aboutData();
+        dlg.insert( (*act)->actionCollection(),dat->programName() );
+    }
+    dlg.configure();
 }
 
 void KitaMainWindow::optionsConfigureToolbars()
 {
     // use the standard toolbar editor
-    KEditToolbar dlg( actionCollection() );
+    KEditToolbar dlg( factory() );
     connect( &dlg, SIGNAL( newToolbarConfig() ),
              SLOT( newToolbarConfig() ) );
     dlg.exec();
@@ -393,23 +466,29 @@ void KitaMainWindow::newToolbarConfig()
 {
     // this slot is called when user clicks "Ok" or "Apply" in the toolbar editor.
     // recreate our GUI, and re-apply the settings (e.g. "text under icons", etc.)
-    createGUI();
+    applyMainWindowSettings( KGlobal::config(), "MainWindow" );
 }
 
 void KitaMainWindow::windowShowBoardlist()
 {
-    if ( m_boardListAction->isChecked() ) {
+    if ( m_boardListAction->isChecked() )
+    {
         makeDockVisible( m_boardDock );
-    } else {
+    }
+    else
+    {
         makeDockInvisible( m_boardDock );
     }
 }
 
 void KitaMainWindow::windowShowSubjectlist()
 {
-    if ( m_subjectListAction->isChecked() ) {
+    if ( m_subjectListAction->isChecked() )
+    {
         makeDockVisible( m_subjectDock );
-    } else {
+    }
+    else
+    {
         makeDockInvisible( m_subjectDock );
     }
 }
@@ -420,10 +499,27 @@ void KitaMainWindow::resetWindows()
     m_subjectDock->manualDock( m_mainDock, KDockWidget::DockTop, 30 );
 }
 
+
+void KitaMainWindow::windowToggleView()
+{
+    //FIXME: m_subjectDock->dockSite() & KDockWidget::DockCenter != 0 ʳΤȤϤɤ롩
+    kdDebug() << "Do toggle" << endl;
+    if ( !m_subjectListAction->isChecked() ) return;
+    if( !m_subjectDock->isVisible()
+	|| !m_subjectDock->isActiveWindow() ) emit switchSubjectView();
+    else{
+    KDockWidget *w = m_mainDock;
+    kdDebug() << QString( "toggle target: %1" ).arg( w->name() ) << endl;
+    w->makeDockVisible();
+    w->getWidget()->setFocus();
+    }
+}
+
 void KitaMainWindow::windowMenuAboutToShow()
 {
-    m_boardListAction->setChecked( m_boardDock->isVisible() );
-    m_subjectListAction->setChecked( m_subjectDock->isVisible() );
+    //m_boardListAction->setChecked( m_boardDock->isVisible() );
+    //m_subjectListAction->setChecked( m_subjectDock->isVisible() );
+    //m_toggleViewAction->setEnabled(m_subjectDock->dockSite() & KDockWidget::DockCenter);
 }
 
 void KitaMainWindow::windowCloseTab()
@@ -435,12 +531,6 @@ void KitaMainWindow::settingsMenuAboutToShow()
 {
     m_toolbarAction->setChecked( toolBar() ->isVisible() );
     m_statusbarAction->setChecked( statusBar() ->isVisible() );
-    m_showAddressAction->setChecked( KitaConfig::showMailAddress() );
-}
-
-void KitaMainWindow::settingsShowMailAddress()
-{
-    KitaConfig::setShowMailAddresss( m_showAddressAction->isChecked() );
 }
 
 void KitaMainWindow::optionsPreferences()
@@ -450,58 +540,105 @@ void KitaMainWindow::optionsPreferences()
 
     connect( &dlg, SIGNAL( fontChanged( const QFont& ) ),
              SLOT( setFont( const QFont& ) ) );
-    connect( &dlg, SIGNAL( threadFontChanged( const QFont& ) ),
-             SLOT( setThreadFont( const QFont& ) ) );
 
     // XXX
-    dlg.setInitialSize( QSize( 500, 300 ) );
-    if ( dlg.exec() ) {
+    dlg.setInitialSize( QSize( 600, 400 ) );
+    if ( dlg.exec() )
+    {
         // redo your settings
     }
 }
 
-void KitaMainWindow::changeStatusbar( const QString& text )
+void KitaMainWindow::slotSetMainStatusbar( const QString& statusStr )
 {
     // display the text on the statusbar
-    statusBar() ->message( text );
-}
-
-void KitaMainWindow::changeCaption( const QString& text )
-{
-    // display the text on the caption
-    setCaption( text );
+    statusBar() ->message( statusStr );
 }
 
 void KitaMainWindow::setupView()
 {
-    m_mainDock = createDockWidget( "main", 0L, 0L, i18n( "main" ) );
+    m_mainDock = createDockWidget( "main", 0L, 0L, i18n( "main" ), i18n( "main" ) );
     m_threadTab = new KitaThreadTabWidget( m_mainDock );
     m_mainDock->setWidget( m_threadTab );
     m_mainDock->setDockSite( KDockWidget::DockFullSite );
     m_mainDock->setEnableDocking( KDockWidget::DockNone );
-    connect( m_threadTab, SIGNAL( openURLRequest( const KURL&, const KParts::URLArgs& ) ),
+    connect( Kita::SignalCollection::getInstance(), SIGNAL( openURLRequest( const KURL&, const KParts::URLArgs& ) ),
              SLOT( slotOpenURLRequest( const KURL&, const KParts::URLArgs& ) ) );
 
-    m_subjectDock = createDockWidget( "subject", 0L, 0L, i18n( "subject" ) );
-    m_subjectTab = new KitaSubjectTabWidget( m_subjectDock );
-    m_subjectDock->setWidget( m_subjectTab );
-    m_subjectDock->setDockSite( KDockWidget::DockNone );
+    /* emit when this widget is deactivated */
+    connect( this, SIGNAL( windowDeactivated() ),
+             Kita::SignalCollection::getInstance(), SIGNAL( windowDeactivated() ));
 
-    m_boardDock = createDockWidget( "board", 0L, 0L, i18n( "board" ) );
-    m_boardView = new KitaBoardView( m_boardDock );
-    m_boardDock->setWidget( m_boardView );
-    m_boardDock->setDockSite( KDockWidget::DockNone );
+    /* If this widget is active and receives
+       signal isKitaActive, then emit signal kitaIsActive. */
+    connect( Kita::SignalCollection::getInstance(), SIGNAL( isKitaActive() ),
+             this, SLOT( slotIsKitaActive() ) );
+
+    connect( this, SIGNAL( kitaIsActive() ),
+             Kita::SignalCollection::getInstance(), SIGNAL( kitaIsActive() ) );
 
     setView( m_mainDock );
     setMainDockWidget( m_mainDock );
 
+    m_subjectDock = createDockWidget( "subject", 0L, 0L, i18n( "subject" ), i18n( "subject" ) );
+    m_subjectTab = new KitaSubjectTabWidget( m_subjectDock );
+    m_subjectDock->setWidget( m_subjectTab );
+    m_subjectDock->setDockSite( KDockWidget::DockNone );
+    connect( m_subjectDock, SIGNAL( headerCloseButtonClicked() ), SLOT( closeSubjectView() ) );
+    connect( m_subjectDock, SIGNAL( iMBeingClosed() ), SLOT( closeSubjectView() ) );
+
+    m_boardDock = createDockWidget( "board", 0L, 0L, i18n( "board" ), i18n( "board" ) );
+    m_boardView = new KitaBoardView( m_boardDock );
+    m_boardDock->setWidget( m_boardView );
+    m_boardDock->setDockSite( KDockWidget::DockNone );
+    connect( m_boardDock, SIGNAL( headerCloseButtonClicked() ), SLOT( closeBoardView() ) );
+    connect( m_boardDock, SIGNAL( iMBeingClosed() ), SLOT( closeBoardView() ) );
+
     m_boardDock->manualDock( m_mainDock, KDockWidget::DockLeft, 20 );
     m_subjectDock->manualDock( m_mainDock, KDockWidget::DockTop, 30 );
+
+    /* setup kitanavi */
+    KitaNavi::createKitaNavi(this,m_threadTab);
 }
 
-void KitaMainWindow::slotOpenURLRequest( const KURL& url, const KParts::URLArgs& )
+void KitaMainWindow::closeSubjectView()
 {
-    new KRun( url );
+    m_subjectListAction->setChecked( FALSE );
+}
+
+void KitaMainWindow::closeBoardView()
+{
+    m_boardListAction->setChecked( FALSE );
+}
+
+void KitaMainWindow::slotOpenURLRequest( const KURL& url, const KParts::URLArgs& args )
+{
+    kdDebug() << QString( "Requested OpenURL: \"%1\"" ).arg( url.url() ) << endl;
+    kdDebug() << QString( "content type: \"%1\"" ).arg( args.contentType() ) << endl;
+    kdDebug() << QString( "service type: \"%1\"" ).arg( args.serviceType ) << endl;
+    kdDebug() << QString( "NewTab: %1, reload: %2" )
+    .arg( args.newTab() ? "yes" : "no" )
+    .arg( args.reload ? "yes" : "no" ) << endl;
+    KURL datURL = Kita::ParseMisc::parseURLonly( url );
+
+    QRegExp regexp( "http://([^/]*)/([^/]*)/dat/(.*)\\.dat" );
+    if ( regexp.search( datURL.url() ) == -1 ) {
+        if ( KitaConfig::usePart() ) {
+            QString mimetype = KIO::NetAccess::mimetype( url );
+            kdDebug() << QString( "queried MIME type: \"%1\"" ).arg( mimetype ) << endl;
+            if ( KitaConfig::partMimeList().find( mimetype ) != KitaConfig::partMimeList().end() ) {
+                KService::Ptr service = KServiceTypeProfile::preferredService( mimetype, "KParts/ReadOnlyPart" );
+                if ( service ) {
+                    QString libName = QFile::encodeName( service->library() );
+                    m_threadTab->showAlternativeView( url, libName, mimetype );
+                    return;
+                }
+            }
+        }
+        new KRun( url );
+    } else {
+        m_threadTab->showThread( url.prettyURL(), true );
+    }
 }
 
 void KitaMainWindow::loadCache()
@@ -509,7 +646,8 @@ void KitaMainWindow::loadCache()
     KitaThreadInfo * cache = KitaThreadInfo::getInstance();
     QString cacheConfigPath = locateLocal( "appdata", "cache" );
     QFile file( cacheConfigPath );
-    if ( file.open( IO_ReadOnly ) ) {
+    if ( file.open( IO_ReadOnly ) )
+    {
         QDataStream stream( &file );
         stream >> *cache;
     }
@@ -520,7 +658,8 @@ void KitaMainWindow::saveCache()
     KitaThreadInfo * cache = KitaThreadInfo::getInstance();
     QString cacheConfigPath = locateLocal( "appdata", "cache" );
     QFile file( cacheConfigPath );
-    if ( file.open( IO_WriteOnly ) ) {
+    if ( file.open( IO_WriteOnly ) )
+    {
         QDataStream stream( &file );
         stream << *cache;
     }
@@ -532,16 +671,10 @@ void KitaMainWindow::saveCache()
 
 void KitaMainWindow::setFont( const QFont& font )
 {
-    KitaConfig::setFont( font );
     m_subjectTab->setFont( font );
     m_boardView->setFont( font );
 }
 
-void KitaMainWindow::setThreadFont( const QFont& font )
-{
-    KitaConfig::setThreadFont( font );
-    m_threadTab->setFont( font );
-}
 
 void KitaMainWindow::slotWriteSucceeded()
 {
@@ -553,23 +686,27 @@ void KitaMainWindow::setUrl( const KURL& url )
     m_urlLine->setText( url.url() );
 }
 
-void KitaMainWindow::bookmark( const Kita::Thread* thread, bool on )
+void KitaMainWindow::bookmark( const QString& datURL, bool on )
 {
-    KitaThreadInfo::setResNum( thread->datURL(), thread->resNum() );
-    FavoriteThreads* favorite = FavoriteThreads::getInstance();
+    FavoriteThreads * favorite = FavoriteThreads::getInstance();
 
-    if ( on ) {
-        favorite->insert( thread->datURL() );
-    } else {
-        favorite->remove( thread->datURL() );
+    if ( on )
+    {
+        favorite->insert( datURL );
     }
+    else
+    {
+        favorite->remove( datURL );
+    }
+    emit favoritesUpdated();
 }
 
 void KitaMainWindow::loadFavorites()
 {
     QString favoritesConfigPath = locateLocal( "appdata", "favorites.xml" );
     QFile file( favoritesConfigPath );
-    if ( file.open( IO_ReadOnly ) ) {
+    if ( file.open( IO_ReadOnly ) )
+    {
         QTextStream stream( &file );
         stream.setEncoding( QTextStream::UnicodeUTF8 );
 
@@ -582,7 +719,8 @@ void KitaMainWindow::saveFavorites()
 {
     QString favoritesConfigPath = locateLocal( "appdata", "favorites.xml" );
     QFile file( favoritesConfigPath );
-    if ( file.open( IO_WriteOnly ) ) {
+    if ( file.open( IO_WriteOnly ) )
+    {
         QTextStream stream( &file );
         stream.setEncoding( QTextStream::UnicodeUTF8 );
         stream << FavoriteThreads::getInstance() ->toXML();
@@ -610,15 +748,18 @@ void KitaMainWindow::loadAsciiArt()
 {
     QString configPath = locateLocal( "appdata", "asciiart" );
     QFile file( configPath );
-    if ( file.open( IO_ReadOnly ) ) {
+    if ( file.open( IO_ReadOnly ) )
+    {
         QTextStream stream( &file );
         stream.setEncoding( QTextStream::UnicodeUTF8 );
 
         QStringList list;
         QString str;
 
-        while ( ( str = stream.readLine() ) != QString::null ) {
-            if ( ! str.isEmpty() ) {
+        while ( ( str = stream.readLine() ) != QString::null )
+        {
+            if ( ! str.isEmpty() )
+            {
                 list << str;
             }
         }
@@ -630,13 +771,15 @@ void KitaMainWindow::saveAsciiArt()
 {
     QString configPath = locateLocal( "appdata", "asciiart" );
     QFile file( configPath );
-    if ( file.open( IO_WriteOnly ) ) {
+    if ( file.open( IO_WriteOnly ) )
+    {
         QTextStream stream( &file ) ;
         stream.setEncoding( QTextStream::UnicodeUTF8 );
 
         QStringList list = KitaConfig::asciiArtList();
         QStringList::iterator it;
-        for ( it = list.begin(); it != list.end(); ++it ) {
+        for ( it = list.begin(); it != list.end(); ++it )
+        {
             stream << ( *it ) << endl;
         }
     }
@@ -646,7 +789,8 @@ void KitaMainWindow::loadFavoriteBoards()
 {
     QString configPath = locateLocal( "appdata", "favorite_boards.xml" );
     QFile file( configPath );
-    if ( file.open( IO_ReadOnly ) ) {
+    if ( file.open( IO_ReadOnly ) )
+    {
         QTextStream stream( &file );
         stream.setEncoding( QTextStream::UnicodeUTF8 );
 
@@ -659,26 +803,175 @@ void KitaMainWindow::saveFavoriteBoards()
 {
     QString configPath = locateLocal( "appdata", "favorite_boards.xml" );
     QFile file( configPath );
-    if ( file.open( IO_WriteOnly ) ) {
+    if ( file.open( IO_WriteOnly ) )
+    {
         QTextStream stream( &file );
         stream.setEncoding( QTextStream::UnicodeUTF8 );
         stream << Kita::FavoriteBoards::toXML();
     }
 }
 
-void KitaMainWindow::slotThread( const Kita::Thread* thread )
+void KitaMainWindow::loadAboneIDList()
 {
-    setCaption( thread->name() );
+    QString configPath = locateLocal( "appdata", "abone_id" );
+    QFile file( configPath );
+    if ( file.open( IO_ReadOnly ) )
+    {
+        QTextStream stream( &file );
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+
+        QStringList list;
+        QString str;
+
+        while ( ( str = stream.readLine() ) != QString::null )
+        {
+            if ( ! str.isEmpty() )
+            {
+                list << str;
+            }
+        }
+        KitaConfig::setAboneIDList( list );
+    }
+}
+
+void KitaMainWindow::saveAboneIDList()
+{
+    QString configPath = locateLocal( "appdata", "abone_id" );
+    QFile file( configPath );
+    if ( file.open( IO_WriteOnly ) )
+    {
+        QTextStream stream( &file ) ;
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+
+        QStringList list = KitaConfig::aboneIDList();
+        QStringList::iterator it;
+        for ( it = list.begin(); it != list.end(); ++it )
+        {
+            stream << ( *it ) << endl;
+        }
+    }
+}
+
+void KitaMainWindow::loadAboneNameList()
+{
+    QString configPath = locateLocal( "appdata", "abone_name" );
+    QFile file( configPath );
+    if ( file.open( IO_ReadOnly ) )
+    {
+        QTextStream stream( &file );
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+
+        QStringList list;
+        QString str;
+
+        while ( ( str = stream.readLine() ) != QString::null )
+        {
+            if ( ! str.isEmpty() )
+            {
+                list << str;
+            }
+        }
+        KitaConfig::setAboneNameList( list );
+    }
+}
+
+void KitaMainWindow::saveAboneNameList()
+{
+    QString configPath = locateLocal( "appdata", "abone_name" );
+    QFile file( configPath );
+    if ( file.open( IO_WriteOnly ) )
+    {
+        QTextStream stream( &file ) ;
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+
+        QStringList list = KitaConfig::aboneNameList();
+        QStringList::iterator it;
+        for ( it = list.begin(); it != list.end(); ++it )
+        {
+            stream << ( *it ) << endl;
+        }
+    }
+}
+
+void KitaMainWindow::loadAboneWordList()
+{
+    QString configPath = locateLocal( "appdata", "abone_word" );
+    QFile file( configPath );
+    if ( file.open( IO_ReadOnly ) )
+    {
+        QTextStream stream( &file );
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+
+        QStringList list;
+        QString str;
+
+        while ( ( str = stream.readLine() ) != QString::null )
+        {
+            if ( ! str.isEmpty() )
+            {
+                list << str;
+            }
+        }
+        KitaConfig::setAboneWordList( list );
+    }
+}
+
+void KitaMainWindow::saveAboneWordList()
+{
+    QString configPath = locateLocal( "appdata", "abone_word" );
+    QFile file( configPath );
+    if ( file.open( IO_WriteOnly ) )
+    {
+        QTextStream stream( &file ) ;
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+
+        QStringList list = KitaConfig::aboneWordList();
+        QStringList::iterator it;
+        for ( it = list.begin(); it != list.end(); ++it )
+        {
+            stream << ( *it ) << endl;
+        }
+    }
+}
+
+void KitaMainWindow::slotSwitchSubjectView()
+{
+    if ( m_subjectListAction->isChecked() )
+        m_subjectDock->makeDockVisible();
+}
+
+void KitaMainWindow::switchThreadView( const QString&, bool )
+{
+    m_mainDock->makeDockVisible();
+}
+
+void KitaMainWindow::slotSetMainCaption( const QString& captionStr )
+{
+    setCaption( captionStr );
 }
 
 void KitaMainWindow::slotEditCopy()
 {
     QWidget * widget = kapp->focusWidget();
 
-    if ( widget ) {
+    if ( widget )
+    {
         QKeyEvent e( QEvent::KeyPress, Key_C, 'C', ControlButton );
         QApplication::sendEvent( widget, &e );
     }
 }
 
+/* when window is deactivated, emit signal to popup */ /* protected */
+void KitaMainWindow::windowActivationChange ( bool  )
+{
+    if(!isActiveWindow()) emit windowDeactivated();
+}
+
+/* private slot */
+void KitaMainWindow::slotIsKitaActive()
+{
+    if(isActiveWindow()) emit kitaIsActive();
+}
+
+
 #include "kita.moc"
