@@ -16,11 +16,7 @@
 #endif
 
 #include <kapplication.h>
-#include <kdockwidget.h>
-
-#include "kitaconfig.h"
-
-#include "libkita/thread.h"
+#include <kparts/dockmainwindow.h>
 
 class KPrinter;
 class KToggleAction;
@@ -33,7 +29,8 @@ class KLineEdit;
 namespace KParts
 {
     class URLArgs;
-};
+    class Part;
+}
 
 /**
  * This class serves as the main window for Kita.  It handles the
@@ -44,7 +41,7 @@ namespace KParts
  * @version $APP_VERSION
  */
 
-class KitaMainWindow : public KDockMainWindow
+class KitaMainWindow : public KParts::DockMainWindow
 {
     Q_OBJECT
 public:
@@ -86,6 +83,8 @@ protected:
     void readConfig( KConfig* );
     void writeConfig( KConfig* );
 
+    void windowActivationChange( bool );
+
 private slots:
     void fileNew();
     void optionsShowToolbar();
@@ -96,23 +95,26 @@ private slots:
     void newToolbarConfig();
     void windowShowBoardlist();
     void windowShowSubjectlist();
+    void windowToggleView();
     void windowMenuAboutToShow();
     void windowCloseTab();
     void settingsMenuAboutToShow();
-    void settingsShowMailAddress();
     void slotEditCopy();
     void resetWindows();
+    void closeSubjectView();
+    void closeBoardView();
 
-    void changeStatusbar( const QString& text );
-    void changeCaption( const QString& text );
+    void slotSetMainStatusbar( const QString& statusStr );
     void slotOpenURLRequest( const KURL& url, const KParts::URLArgs& );
     void setFont( const QFont& font );
-    void setThreadFont( const QFont& font );
     void slotWriteSucceeded();
-    void slotUrlLine();
+    void slotURLLine();
     void setUrl( const KURL& url );
-    void bookmark( const Kita::Thread* thread, bool on );
-    void slotThread( const Kita::Thread* thread );
+    void bookmark( const QString& datURL, bool on );
+    void slotSetMainCaption( const QString& captionStr );
+    void slotIsKitaActive();
+    void slotSwitchSubjectView();
+    void switchThreadView( const QString&, bool );
 
 private:
     KitaThreadTabWidget* m_threadTab;
@@ -125,7 +127,7 @@ private:
     KToggleAction *m_statusbarAction;
     KToggleAction *m_boardListAction;
     KToggleAction* m_subjectListAction;
-    KToggleAction* m_showAddressAction;
+    KAction* m_toggleViewAction;
 
     KDockWidget* m_mainDock;
     KDockWidget* m_boardDock;
@@ -144,6 +146,19 @@ private:
     void saveCompletion();
     void loadAsciiArt();
     void saveAsciiArt();
+    void loadAboneIDList();
+    void saveAboneIDList();
+    void loadAboneNameList();
+    void saveAboneNameList();
+    void loadAboneWordList();
+    void saveAboneWordList();
+    
+  signals:
+    void windowDeactivated();
+    void isKitaActive();
+    void kitaIsActive();
+    void favoritesUpdated();
+    void switchSubjectView();
 };
 
 #endif // _KITA_H_
