@@ -20,15 +20,19 @@
 #include <krun.h>
 #include <kdebug.h>
 #include <qvaluelist.h>
+#include <qheader.h>
 
-#include "libkita/qcp932codec.h"
-#include "libkita/favoriteboards.h"
-#include "part/kita2ch.h"
 #include "kitaboardview.h"
 #include "kita.h"
+#include "part/kita2ch.h"
+#include "libkita/qcp932codec.h"
+#include "libkita/favoriteboards.h"
 #include "libkita/board.h"
 #include "libkita/category.h"
+#include "libkita/kitaconfig.h"
+#include "libkita/signalcollection.h"
 
+QCp932Codec* KitaBoardView::m_cp932Codec = NULL;
 
 KitaBoardView::KitaBoardView( QWidget *parent, const char *name )
         : KitaBoardViewBase( parent, name )
@@ -36,11 +40,17 @@ KitaBoardView::KitaBoardView( QWidget *parent, const char *name )
 {
     m_boardList->setSorting( -1 );
     m_boardList->addColumn( i18n( "board name" ) );
+    m_boardList->header()->setClickEnabled( FALSE );
+    
+    Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
     connect( m_boardList, SIGNAL( mouseButtonClicked( int, QListViewItem*, const QPoint&, int ) ),
              SLOT( slotMouseButtonClicked( int, QListViewItem* ) ) );
     connect( m_boardList, SIGNAL( returnPressed( QListViewItem* ) ), SLOT( loadBoard( QListViewItem* ) ) );
     connect( m_boardList, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
              SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
+    connect( Kita::FavoriteBoards::getInstance(), SIGNAL( changed() ), SLOT( refreshFavoriteBoards() ) );
+    connect( this, SIGNAL( openBoardRequested( const QString&, bool ) ),
+             signalCollection, SIGNAL( openBoardRequested( const QString&, bool ) ) );
 }
 
 KitaBoardView::~KitaBoardView()
@@ -56,20 +66,20 @@ QString KitaBoardView::getCategory( const QString& line ) const
     }
 }
 
-Kita::Board* KitaBoardView::getBoard( const QString& line ) const
+QString KitaBoardView::getBoardURL( const QString& line ) const
 {
     QRegExp regexp( "<A HREF=([^ ]*).*>(.*)</A>", false );
     if ( regexp.search( line ) != -1 ) {
         QString board_url = regexp.cap( 1 );
         QString board_title = regexp.cap( 2 );
         Kita::Board::setName( board_url, board_title );
-        return Kita::Board::getByURL( board_url );
+        return board_url;
     } else {
-        return Kita::Board::getByURL( QString::null );
+        return QString::null;
     }
 }
 
-bool KitaBoardView::isBoardUrl( const QString& url ) const
+bool KitaBoardView::isBoardURL( const QString& url ) const
 {
     QRegExp url_2ch( "http://.*\\.2ch\\.net/.*" );
     QRegExp url_bbspink( "http://.*\\.bbspink\\.com/.*" );
@@ -99,28 +109,32 @@ void KitaBoardView::loadBoardList()
     }
 
     QTextStream stream( &file );
-    QCp932Codec cp932Codec;
-    stream.setCodec( &cp932Codec );
-    QPtrList<Kita::Category> categoryList = getCategoryList( stream.read() );
+    if( !m_cp932Codec ) m_cp932Codec = new QCp932Codec();
+    stream.setCodec( m_cp932Codec );
+    QValueList<Kita::Category> categoryList = getCategoryList( stream.read() );
 
     // clear list
     m_boardList->clear();
+    m_favorites = NULL;
 
     KListViewItem* previous = 0;
-    for ( Kita::Category * category = categoryList.first(); category; category = categoryList.next() ) {
-        QPtrList<Kita::Board> board_list = category->getBoardList();
+    QValueList<Kita::Category>::iterator it;
+    for ( it = categoryList.begin(); it != categoryList.end(); ++it ) {
+        Kita::Category category = (*it);
+        QValueList<QString> board_url_list = category.getBoardURLList();
 
-        if ( board_list.isEmpty() ) {
+        if ( board_url_list.isEmpty() ) {
             continue;
         }
 
-        KListViewItem* categoryItem = new KListViewItem( m_boardList, previous, category->name() );
+        KListViewItem* categoryItem = new KListViewItem( m_boardList, previous, category.name() );
 
         KListViewItem* previousBoard = 0;
-        QPtrListIterator<Kita::Board> it( board_list );
-        for ( ; *it; ++it ) {
-            Kita::Board* board = *it;
-            previousBoard = new KListViewItem( categoryItem, previousBoard, board->name(), board->url() );
+        QValueList<QString>::iterator it;
+        for ( it = board_url_list.begin(); it != board_url_list.end(); ++it ) {
+            QString boardURL = *it;
+            QString boardName = Kita::Board::getName( *it );
+            previousBoard = new KListViewItem( categoryItem, previousBoard, boardName, boardURL );
         }
         previous = categoryItem;
     }
@@ -128,25 +142,27 @@ void KitaBoardView::loadBoardList()
     refreshFavoriteBoards();
 }
 
-QPtrList<Kita::Category> KitaBoardView::getCategoryList( const QString& html ) const
+QValueList<Kita::Category> KitaBoardView::getCategoryList( const QString& html ) const
 {
-    QPtrList<Kita::Category> result;
+    QValueList<Kita::Category> result;
 
     QStringList lines = QStringList::split( "\n", html );
     QStringList::iterator it;
 
-    Kita::Category* current_category = 0;
+    Kita::Category current_category;
     for ( it = lines.begin(); it != lines.end(); ++it ) {
         QString category_name = getCategory( *it );
         if ( category_name != QString::null ) {
-            current_category = new Kita::Category( category_name );
-            result.append( current_category );
+            if ( ! current_category.name().isEmpty() ) {
+                result.append( current_category );
+            }
+            current_category = Kita::Category( category_name );
         } else {
-            Kita::Board* board = getBoard( *it );
+            QString boardURL = getBoardURL( *it );
 
-            if ( isBoardUrl( board->url() ) ) {
-                if ( current_category ) {
-                    current_category->append( board );
+            if ( isBoardURL( boardURL ) ) {
+                if ( ! current_category.name().isEmpty() ) {
+                    current_category.append( boardURL );
                 }
             }
         }
@@ -170,7 +186,7 @@ void KitaBoardView::refreshFavoriteBoards()
 
     for ( it = boards.begin(); it != boards.end(); ++it ) {
         QString boardURL = ( *it ).url();
-        QString boardName = Kita::Board::getByURL( boardURL ) ->name();
+        QString boardName = Kita::Board::getName( boardURL );
         new KListViewItem( m_favorites, 0, boardName, boardURL );
     }
 }
@@ -224,11 +240,9 @@ void KitaBoardView::slotContextMenuRequested( QListViewItem* item, const QPoint&
         break;
     case 2:
         Kita::FavoriteBoards::append( url );
-        refreshFavoriteBoards();
         break;
     case 3:
         Kita::FavoriteBoards::remove( url );
-        refreshFavoriteBoards();
         break;
     default:
         break;
@@ -242,11 +256,12 @@ void KitaBoardView::slotMouseButtonClicked( int button, QListViewItem* item )
     QString boardName = item->text( 0 );
     QString boardURL = item->text( 1 );
     if ( boardURL.isEmpty() ) {
+        m_boardList->setOpen( item, !item->isOpen() );
         return ;
     }
-    
-    Kita::Board* board = Kita::Board::getByURL( boardURL );
 
+    emit sigShowSubject();
+    
     switch ( button ) {
     case MidButton:
         emit openBoardRequested( boardURL, true );
