@@ -18,6 +18,8 @@
 #include <qapplication.h>
 #include <qclipboard.h>
 
+#include "libkita/signalcollection.h"
+
 KitaSubjectTabWidget::KitaSubjectTabWidget( QWidget* parent, const char* name, WFlags f )
         : QTabWidget( parent, name, f )
 {
@@ -35,86 +37,98 @@ KitaSubjectTabWidget::KitaSubjectTabWidget( QWidget* parent, const char* name, W
     connect( view, SIGNAL( loadBoardCompleted( const KURL& ) ),
              this, SIGNAL( loadBoardCompleted( const KURL& ) ) );
 
+    Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
     connect( this, SIGNAL( currentChanged( QWidget* ) ),
              SLOT( slotCurrentChanged( QWidget* ) ) );
     connect( tabBar(), SIGNAL( deleteMenuSelected( KitaSubjectView* ) ),
              SLOT( deleteView( KitaSubjectView* ) ) );
+    connect( signalCollection, SIGNAL( openBoardRequested( const QString&, bool ) ),
+             SLOT( loadBoard( const QString&, bool ) ) );
+    connect( this, SIGNAL( switchSubjectView() ),
+             signalCollection, SIGNAL( switchSubjectView() ) );
+    connect( signalCollection, SIGNAL( switchSubjectView() ),
+	     SLOT( slotSwitchSubjectView() ));
 }
 
 KitaSubjectTabWidget::~KitaSubjectTabWidget()
 {}
 
-void KitaSubjectTabWidget::loadBoard( const Kita::Board* board, bool withNewTab )
+void KitaSubjectTabWidget::loadBoard( const QString& boardURL, bool withNewTab )
 {
-    KitaSubjectView * view = findView( board->url() );
-    if ( view ) {
+    emit switchSubjectView();
+    KitaSubjectView * view = findView( boardURL );
+    QString boardName = Kita::Board::getName( boardURL );
+    if ( view )
+    {
         m_latestView = view;
-        setTabLabel( m_latestView, board->name() );
-    } else if ( withNewTab ) {
+        setTabLabel( m_latestView, boardName );
+    }
+    else if ( withNewTab )
+    {
         KitaSubjectView * newView = new KitaSubjectView( this );
         connectSignals( newView );
         connect( newView, SIGNAL( loadBoardCompleted( const KURL& ) ),
                  this, SIGNAL( loadBoardCompleted( const KURL& ) ) );
-        insertTab( newView, board->name(), count() - 1 );
+        insertTab( newView, boardName, count() - 1 );
         m_latestView = newView;
         m_viewList.append( newView );
-    } else {
-        setTabLabel( m_latestView, board->name() );
+    }
+    else
+    {
+        setTabLabel( m_latestView, boardName );
     }
 
-    m_latestView->loadBoard( board );
+    m_latestView->loadBoard( boardURL );
 
     showPage( m_latestView );
 }
 
-void KitaSubjectTabWidget::loadBoard( const QString& boardURL, bool withNewTab )
+/* private slot */
+void KitaSubjectTabWidget::slotSwitchSubjectView()
 {
-    Kita::Board * board = Kita::Board::getByURL( boardURL );
-    loadBoard( board, withNewTab );
-}
-
-void KitaSubjectTabWidget::updateThread( const Kita::Thread* thread )
-{
-    for ( int i = 0; i < count(); i++ ) {
-        QWidget* widget = page( i );
-        // TODO: classȽꤷ褦
-        if ( QString::compare( widget->name(), "favoriteTab" ) == 0 ) {
-            static_cast<FavoriteListView*>( widget ) ->updateThread( thread );
-        } else {
-            static_cast<KitaSubjectView*>( widget ) ->updateThread( thread );
-        }
-    }
+    m_latestView->setFocusList();
 }
 
 void KitaSubjectTabWidget::connectSignals( Kita::ThreadListView* view )
 {
-    connect( view, SIGNAL( showThreadRequested( const Kita::Thread*, bool ) ),
-             this, SIGNAL( showThreadRequested( const Kita::Thread*, bool ) ) );
+    connect( view, SIGNAL( showThreadRequested( const QString&, bool ) ),
+             this, SIGNAL( showThreadRequested( const QString&, bool ) ) );
 }
 
 KitaSubjectView* KitaSubjectTabWidget::findView( const QString& boardURL )
 {
     KitaSubjectView * view;
-    for ( view = m_viewList.first(); view; view = m_viewList.next() ) {
-        if ( view->boardURL() == boardURL ) {
+    for ( view = m_viewList.first(); view; view = m_viewList.next() )
+    {
+        if ( view->boardURL() == boardURL )
+        {
             return view;
         }
+        if ( view->boardURL().isEmpty() )
+        {
+            return view;  // default view
+        }
     }
     return 0;
 }
 
 void KitaSubjectTabWidget::slotCurrentChanged( QWidget* widget )
 {
-    if ( QString::compare( widget->name(), "favoriteTab" ) == 0 ) {
+    if ( QString::compare( widget->name(), "favoriteTab" ) == 0 )
+    {
         m_favoriteList->update();
-    } else {
+    }
+    else
+    {
         m_latestView = static_cast<KitaSubjectView*>( widget );
+	m_latestView->setFocusList();
     }
 }
 
 void KitaSubjectTabWidget::deleteView( KitaSubjectView* view )
 {
-    if ( count() <= 2 ) {
+    if ( count() <= 2 )
+    {
         return ;
         // favoriteȤΤȤϲ⤷ʤ
     }
@@ -127,6 +141,12 @@ void KitaSubjectTabWidget::deleteView( KitaSubjectView* view )
     m_latestView = static_cast<KitaSubjectView *>( currentPage() );
 }
 
+void KitaSubjectTabWidget::reloadSubjectList()
+{
+    if ( !m_latestView )
+        m_latestView->reloadSubject();
+}
+
 Kita::SubjectTabBar::SubjectTabBar( QWidget* parent, const char* name )
         : QTabBar( parent, name )
 {}
@@ -144,13 +164,15 @@ void Kita::SubjectTabBar::contextMenuEvent( QContextMenuEvent* e )
 
     QTabWidget* parent = static_cast<QTabWidget *>( parentWidget() );
     // FIXME: ޤȤȽȤ
-    if ( QString::compare( parent->currentPage() ->name(), "favoriteTab" ) == 0 ) {
+    if ( QString::compare( parent->currentPage() ->name(), "favoriteTab" ) == 0 )
+    {
         return ;
     }
     KitaSubjectView* subjectView = static_cast<KitaSubjectView *>( parent->currentPage() );
     QClipboard* clipboard = QApplication::clipboard();
 
-    switch ( popup.exec( e->globalPos() ) ) {
+    switch ( popup.exec( e->globalPos() ) )
+    {
     case 0:
         KRun::runURL( subjectView->boardURL(), "text/html" );
         break;
