@@ -29,9 +29,8 @@ public:
     ~KitaSubjectTabWidget();
 
 public slots:
-    void loadBoard( const Kita::Board*, bool withNewTab = false );
     void loadBoard( const QString&, bool withNewTab = false );
-    void updateThread( const Kita::Thread* );
+    void reloadSubjectList();
 
 private:
     FavoriteListView* m_favoriteList;
@@ -43,10 +42,12 @@ private:
 private slots:
     void slotCurrentChanged( QWidget* widget );
     void deleteView( KitaSubjectView* view );
+    void slotSwitchSubjectView();
 
 signals:
-    void showThreadRequested( const Kita::Thread*, bool withNewTab );
+    void showThreadRequested( const QString&, bool withNewTab );
     void loadBoardCompleted( const KURL& );
+    void switchSubjectView();
 };
 
 namespace Kita
@@ -65,6 +66,6 @@ namespace Kita
     signals:
         void deleteMenuSelected( KitaSubjectView* );
     };
-};
+}
 
 #endif
