@@ -19,6 +19,8 @@
 #include <qclipboard.h>
 #include <qapplication.h>
 #include <qdatetime.h>
+#include <qlabel.h>
+#include <qmessagebox.h>
 
 // kdelibs/kio
 #include <kio/slaveconfig.h>
@@ -37,43 +39,49 @@
 #include "libkita/threadinfo.h"
 #include "libkita/thread.h"
 #include "libkita/kita_misc.h"
+#include "libkita/kitaconfig.h"
+#include "libkita/favoritethreads.h"
+#include "libkita/datmanager.h"
+#include "libkita/parsemisc.h"
+#include "libkita/signalcollection.h"
 #include "part/kita2ch.h"
-#include "kitaconfig.h"
 
 KitaSubjectView::KitaSubjectView( QWidget* parent, const char* name )
         : Kita::ThreadListView( parent, name )
-        , m_board( 0 )
+        , m_unreadNum( 0 ), m_readNum( 0 ), m_newNum( 0 )
 {
     connect( subjectList, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
              SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
-    connect( subjectList, SIGNAL( mouseButtonClicked( int, QListViewItem*, const QPoint&, int ) ),
-             SLOT( slotMouseButtonClicked( int, QListViewItem* ) ) );
     connect( subjectList, SIGNAL( returnPressed( QListViewItem* ) ),
              SLOT( loadThread( QListViewItem* ) ) );
     connect( ReloadButton, SIGNAL( clicked() ),
-             SLOT( slotReloadButton() ) );
+             SLOT( reloadSubject() ) );
+
+    Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
+    connect( signalCollection, SIGNAL( updateSubjectTab( const KURL& ) ),
+             SLOT( slotUpdateSubject( const KURL& ) ) );
+    connect( this, SIGNAL( closeThreadTab( const KURL& ) ),
+	     signalCollection, SIGNAL( closeThreadTab( const KURL& ) ));
 }
 
 KitaSubjectView::~KitaSubjectView()
 {}
 
 void KitaSubjectView::reloadSubject()
-{}
+{
+    if ( ! m_boardURL.isEmpty() ) {
+        loadBoard( m_boardURL );
+    }
+}
 
 const QString KitaSubjectView::boardURL()
 {
-    if ( m_board ) {
-        return m_board->url();
-    }
-    return "";
+    return m_boardURL;
 }
 
 const QString KitaSubjectView::boardName()
 {
-    if ( m_board ) {
-        return m_board->name();
-    }
-    return "";
+    return Kita::Board::getName( m_boardURL );
 }
 
 void KitaSubjectView::loadThread( QListViewItem* item )
@@ -85,13 +93,29 @@ void KitaSubjectView::loadThread( QListViewItem* item )
     Kita::Thread* thread = Kita::Thread::getByURL( datURL.url() );
 
     if ( KitaConfig::alwaysUseTab() ) {
-        emit showThreadRequested( thread, true );
+        emit showThreadRequested( thread->datURL(), true );
     } else {
-        emit showThreadRequested( thread, false );
+        emit showThreadRequested( thread->datURL(), false );
     }
 }
+/*
+ͥ
+ts_readed   : ɤ1000ĶƤ
+ts_normal   : ̤1ʾФäƤ
+ts_new      : ̤1Τ
+ts_read   : ɤ1000ʲΤ
+ts_hasunread: ̤ɤ
+*/
 
-void KitaSubjectView::loadBoard( const Kita::Board* board )
+enum {
+    ts_readed,
+    ts_normal,
+    ts_new,
+    ts_read,
+    ts_hasunread
+};
+
+void KitaSubjectView::loadBoard( const QString& boardURL )
 {
     setActiveWindow();
     topLevelWidget() ->raise();
@@ -105,10 +129,13 @@ void KitaSubjectView::loadBoard( const Kita::Board* board )
         m_prevquery = "";
     }
 
-    m_board = board;
+    m_boardURL = boardURL;
+    m_unreadNum = 0;
+    m_readNum = 0;
+    m_newNum = 0;
 
     KitaThreadInfo* cache = KitaThreadInfo::getInstance();
-    QPtrList<Kita::Thread> threadList = m_board->getThreadList();
+    QPtrList<Kita::Thread> threadList = Kita::Board::getThreadList( boardURL );
 
     // clear list
     subjectList->clear();
@@ -117,7 +144,7 @@ void KitaSubjectView::loadBoard( const Kita::Board* board )
         Kita::Thread* thread = threadList.at( i );
 
         QDateTime since;
-        since.setTime_t( KURL( thread->datURL() ).fileName().section( '.', 0, 0 ).toInt() );
+        since.setTime_t( Kita::datToSince( thread->datURL() ) );
 
         int readNum = cache->readNum( thread->datURL() );
         int resNum = thread->resNum();
@@ -134,42 +161,64 @@ void KitaSubjectView::loadBoard( const Kita::Board* board )
 
         // FIXME: updateThread˥ԡƤ
         // TODO: 'N'Υ
-        /*
-        ͥ
-        0: ɤ1000ĶƤ
-        1: ̤1ʾФäƤ
-        2: ̤1Τ
-        3: ɤ1000ʲΤ
-        4: ̤ɤ
-        */
         if ( readNum > 0 && resNum != readNum ) {
             // ̤ɤ
             item->setPixmap( Col_Mark, SmallIcon( "unread" ) );
-            item->setText( Col_MarkOrder, "4" );
+            m_unreadNum++;
+            item->setText( Col_MarkOrder, QString::number( ts_hasunread ) );
         } else if ( readNum > 0 ) {
             // 
             item->setPixmap( Col_Mark, SmallIcon( "read" ) );
-            if( readNum > 1000 ) {
-                item->setText( Col_MarkOrder, "0" );
-            } else {
-                item->setText( Col_MarkOrder, "3" );
-            }
-        } else if ( since.secsTo( currentdat ) < 3600*24 ){
+            m_readNum++;
+            //if( readNum > 1000) item->setText( Col_MarkOrder, "0" );
+            //else item->setText( Col_MarkOrder, "3" );
+            item->setText( Col_MarkOrder, QString::number( ( readNum > 1000 ) ? ts_readed : ts_read ) );
+        } else if ( since.secsTo( currentdat ) < 3600 * KitaConfig::MarkTime() ) {
             item->setPixmap( Col_Mark, SmallIcon( "newthread" ) );
-            item->setText( Col_MarkOrder, "2" );
+            m_newNum++;
+            item->setText( Col_MarkOrder, QString::number( ts_new ) );
         } else {
-            item->setText( Col_MarkOrder, "1" );
+            item->setText( Col_MarkOrder, QString::number( ts_normal ) );
         }
     }
 
     if ( HideButton->isOn() ) {
         HideButton->toggle();
     }
-    emit loadBoardCompleted( m_board->url() );
+    emit loadBoardCompleted( boardURL );
 
-    subjectList->setSorting( Col_ID );
+    switch ( KitaConfig::sortOrder() ) {
+    case KitaConfig::Order_Mark:
+        subjectList->setSorting( Col_Mark );
+        break;
+    case KitaConfig::Order_ID:
+        subjectList->setSorting( Col_ID );
+        break;
+    default:
+        // do nothing
+        break;
+    }
 
     subjectList->setFocus();
+    UpdateKindLabel();
+}
+
+/* public */
+void KitaSubjectView::setFocusList()
+{
+    setActiveWindow();
+    topLevelWidget()->raise();
+    subjectList->setFocus();
+}
+
+
+void KitaSubjectView::UpdateKindLabel()
+{
+    QString fmtstr;
+    fmtstr += QString( "<font color=#C50000>%1</font>" ).arg( m_unreadNum );
+    fmtstr += QString( "/<font color=#00C200>%1</font>" ).arg( m_readNum );
+    fmtstr += QString( "/<font color=#5AAAFF>%1</font>" ).arg( m_newNum );
+    KindLabel->setText( fmtstr );
 }
 
 void KitaSubjectView::setFont( const QFont& font )
@@ -177,27 +226,51 @@ void KitaSubjectView::setFont( const QFont& font )
     subjectList->setFont( font );
 }
 
-void KitaSubjectView::updateThread( const Kita::Thread* updated_thread )
+void KitaSubjectView::slotUpdateSubject( const KURL& url )
 {
+    QDateTime currentdat = QDateTime::currentDateTime();
+
+    KURL datURL = Kita::ParseMisc::parseURLonly( url );
+    Kita::Thread* updated_thread = Kita::Thread::getByURLNew( datURL );
     for ( QListViewItem * item = subjectList->firstChild(); item; item = item->nextSibling() ) {
-        if ( item->text( Col_DatURL ) == updated_thread->datURL() ) {
+        if ( item->text( Col_DatURL ) == datURL.prettyURL() ) {
+	    QDateTime since;
+	    since.setTime_t( Kita::datToSince( datURL.prettyURL() ) );
+	    
             int resNum = updated_thread->resNum();
             int readNum = KitaThreadInfo::readNum( updated_thread->datURL() );
             item->setText( Col_ResNum, QString( "%1" ).arg( resNum, 4 ) );
-            item->setText( Col_Read, QString( "%1" ).arg( readNum, 4 ) );
+	    item->setText( Col_Read, ( readNum > 0 ) ? QString( "%1" ).arg( readNum, 4 ) : QString( "" ) );
             item->setText( Col_Unread, readNum > 0 && resNum != readNum ? QString( "%1" ).arg( resNum - readNum, 4 ) : QString( "" ) );
 
+            switch ( item->text( Col_MarkOrder ).toInt() ) {
+                case ts_readed    :
+                case ts_read      : m_readNum--; break;
+                case ts_new       : m_newNum--; break;
+                case ts_hasunread : m_unreadNum--; break;
+            }
+
             if ( readNum > 0 && resNum != readNum ) {
                 // ̤ɤ
                 item->setPixmap( Col_Mark, SmallIcon( "unread" ) );
-                item->setText( Col_MarkOrder, "2" );
+                m_unreadNum++;
+                item->setText( Col_MarkOrder, QString::number( ts_hasunread ) );
             } else if ( readNum > 0 ) {
                 // 
                 item->setPixmap( Col_Mark, SmallIcon( "read" ) );
-                item->setText( Col_MarkOrder, "1" );
+                m_readNum++;
+                //if( readNum > 1000) item->setText( Col_MarkOrder, "0" );
+                //else item->setText( Col_MarkOrder, "3" );
+                item->setText( Col_MarkOrder, QString::number( ( readNum > 1000 ) ? ts_readed : ts_read ) );
+            } else if ( since.secsTo( currentdat ) < 3600 * KitaConfig::MarkTime() ) {
+                item->setPixmap( Col_Mark, SmallIcon( "newthread" ) );
+                m_newNum++;
+                item->setText( Col_MarkOrder, QString::number( ts_new ) );
             } else {
-                item->setText( Col_MarkOrder, "0" );
+                item->setPixmap( Col_Mark, NULL );	    
+                item->setText( Col_MarkOrder, QString::number( ts_normal ) );
             }
+            UpdateKindLabel();
         }
     }
 }
@@ -208,13 +281,21 @@ void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoin
         return ;
     }
 
+    Kita::Thread* thread = Kita::Thread::getByURL( item->text( Col_DatURL ) );
+    bool isFavorites = FavoriteThreads::getInstance()->contains( thread->datURL() );
+    
     KPopupMenu popup( 0 );
     popup.insertItem( i18n( "Open with Web Browser" ), 0 );
     popup.insertItem( i18n( "Open with new tab" ), 1 );
     popup.insertItem( i18n( "Copy title and URL" ), 2 );
-
-    Kita::Thread* thread = Kita::Thread::getByURL( item->text( Col_DatURL ) );
-
+    if ( isFavorites ) {
+        popup.insertItem( i18n( "Remove from Favorites" ), 3 );
+    } else {
+        popup.insertItem( i18n( "Add to Favorites" ), 3 );
+    }
+    popup.insertSeparator();
+    popup.insertItem( i18n( "Delete Log" ), 4 );
+    
     QClipboard* clipboard = QApplication::clipboard();
 
     switch ( popup.exec( point ) ) {
@@ -222,41 +303,36 @@ void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoin
         KRun::runURL( thread->url(), "text/html" );
         break;
     case 1:
-        emit showThreadRequested( thread, true );
+        emit showThreadRequested( thread->datURL(), true );
         break;
     case 2:
         clipboard->setText( thread->name() + "\n" + thread->url() );
         break;
+    case 3:
+        if ( isFavorites ) {
+            emit bookmarked( thread->datURL(), false );
+        } else {
+            emit bookmarked( thread->datURL(), true );
+        }
+        break;
+    case 4:
+        deleteLog( Kita::DatManager::threadURL( thread->datURL() ) );
+        break;
     default:
         break;
     }
 }
 
-void KitaSubjectView::slotReloadButton()
+void KitaSubjectView::deleteLog( const KURL& url )
 {
-    if ( m_board ) {
-        loadBoard( m_board );
-    }
-}
-
-void KitaSubjectView::slotMouseButtonClicked( int button, QListViewItem* item )
-{
-    if ( ! item ) return ;
-
-    KURL datURL = item->text( Col_DatURL );
-
-    Kita::Thread* thread = Kita::Thread::getByURL( datURL.url() );
-
-    switch ( button ) {
-    case MidButton:
-        emit showThreadRequested( thread, true );
-        break;
-    case LeftButton:
-        if ( KitaConfig::alwaysUseTab() ) {
-            emit showThreadRequested( thread, true );
-        } else {
-            emit showThreadRequested( thread, false );
-        }
-        break;
+    if ( QMessageBox::warning( this,
+                               "Kita",
+                               i18n( "Do you want to delete Log ?" ),
+                               QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default )
+            == QMessageBox::Ok )
+    {
+        Kita::DatManager::deleteCache( url, this );
+	  emit closeThreadTab( url );
+	  slotUpdateSubject( url );
     }
 }
