@@ -32,25 +32,27 @@ public:
     ~KitaSubjectView();
     const QString boardURL();
     const QString boardName();
+    void setFocusList();
 
 public slots:
     void reloadSubject();
-    void loadBoard( const Kita::Board* board );
+    void loadBoard( const QString& boardURL );
     void setFont( const QFont& font );
-    void updateThread( const Kita::Thread* thread );
+    void slotUpdateSubject( const KURL& url );
 
 private:
-    const Kita::Board* m_board;
+    QString m_boardURL;
+    int m_unreadNum, m_readNum, m_newNum;
+    void UpdateKindLabel();
+    void deleteLog( const KURL& url );
 
 private slots:
     void loadThread( QListViewItem* item );
     void slotContextMenuRequested( QListViewItem*, const QPoint&, int );
-    void slotReloadButton();
-    void slotMouseButtonClicked( int, QListViewItem* );
 
 signals:
     void loadBoardCompleted( const KURL& );
-    void showThreadRequested( const Kita::Thread* thread, bool withNewTab );
+    void closeThreadTab( const KURL& );
 };
 
 #endif
