@@ -14,6 +14,7 @@
 #include <qtabwidget.h>
 #include <qtabbar.h>
 #include <kparts/browserextension.h>
+#include <kparts/partmanager.h>
 
 class KitaThreadPart;
 class KitaThreadView;
@@ -22,7 +23,7 @@ class KURL;
 namespace Kita
 {
     class Thread;
-};
+}
 
 /**
 @author Hideki Ikemoto
@@ -31,37 +32,42 @@ class KitaThreadTabWidget : public QTabWidget
 {
     Q_OBJECT
 
+    KParts::PartManager *m_manager;
+
 public:
     KitaThreadTabWidget( QWidget* parent = 0, const char* name = 0, WFlags f = 0 );
     ~KitaThreadTabWidget();
-    void closeCurrentTab();
+    KParts::Part* findPartFromView( QWidget* );
+    KParts::PartManager* manager() { return m_manager; }
 
 public slots:
-    void showThread( const Kita::Thread* thread );
-    void showThread( const QString& datURL, bool withNewTab = false );
-    void showThread( const Kita::Thread* thread, bool withNewTab );
-    void showThreadWithNewTab( const Kita::Thread* thread ); // ad-hoc
-    void deleteView( KitaThreadView* );
+    void showThread( const QString& datURL, bool withNewTab );
+    void deleteView( QWidget* );
     void reloadThread();
     void focusSearchCombo();
     void slotCurrentChanged( QWidget* );
+    void closeCurrentTab();
+    void slotCloseThreadTab( const KURL& url );
+    void showAlternativeView( const KURL&, const QString&, const QString& );
+
 
 private:
-    void connectSignals( KitaThreadView* );
+    void connectSignals();
     KitaThreadView* createView();
     QPtrList<KitaThreadView> m_viewList;
     KitaThreadView* findView( const QString& threadURL );
+    const QString getTabLabel( const QString &name );
 
 private slots:
-    void slotOpenURLRequest( const KURL& url, const KParts::URLArgs& args = KParts::URLArgs() );
+    void slotUpdateThreadTab( const KURL& url );
 
+protected:
+    virtual void customEvent( QCustomEvent * e );  
+ 
 signals:
-    void openURLRequest( const KURL& url, const KParts::URLArgs &args = KParts::URLArgs() );
-    void signalChangeStatusbar( const QString& );
-    void thread( const Kita::Thread* );
-    void writeSucceeded();
-    void bookmarked( const Kita::Thread*, bool on );
-    void showThreadCompleted( const KURL& threadUrl );
+    void setMainStatusbar( const QString& );
+    void setMainCaption( const QString& );
+    void switchSubjectView();
 };
 
 class KitaThreadTabBar : public QTabBar
@@ -76,7 +82,27 @@ protected:
     virtual void contextMenuEvent( QContextMenuEvent* e );
 
 signals:
-    void deleteMenuSelected( KitaThreadView* );
+    void deleteMenuSelected( QWidget* );
 };
 
+
+/*------------------------------------------------------------------*/
+#include <qevent.h>
+
+#define EVENT_CloseCurrentThreadTab ( QEvent::User + 100 )
+
+
+class CloseCurrentThreadTabEvent : public QCustomEvent
+{
+    int pageindex;
+
+  public:
+
+    CloseCurrentThreadTabEvent( int idx )
+	: QCustomEvent( EVENT_CloseCurrentThreadTab ), pageindex( idx ){}
+
+    const int getIndex() const { return pageindex; }
+};
+
+
 #endif
