@@ -26,14 +26,11 @@
 
 #include "qcp932codec.h"
 
-enum {
-    Board_MachiBBS,
-    Board_2ch
-};
-
 using namespace Kita;
 
 QDict<Board>* Board::m_boardDict = 0;
+QCp932Codec* Board::m_cp932Codec = NULL;
+QEucJpCodec* Board::m_eucJpCodec = NULL;
 
 Board::Board()
 {}
@@ -44,72 +41,50 @@ Board::Board( const QString& boardURL, const QString boardName ) : m_boardURL( b
 Board::~Board()
 {}
 
-const KURL Board::subjectTxtURL() const
+const QString Board::getID( const QString& boardURL )
 {
-    if ( m_boardURL.isEmpty() ) {
-        return KURL();
-    } else {
-        return KURL( m_boardURL, "./subject.txt" );
-    }
+    return KURL( boardURL ).fileName();
 }
 
-const QString& Board::url() const
+const QPtrList<Thread> Board::getThreadList( const QString& boardURL )
 {
-    return m_boardURL;
-}
-
-const QString& Board::name() const
-{
-    return m_boardName;
-}
-
-const QString Board::id() const
-{
-    return KURL( m_boardURL ).fileName();
-}
-
-int Board::type() const
-{
-    QRegExp url_machibbs( "http://.*\\.machi\\.to/.*" );
-    if ( url_machibbs.search( m_boardURL ) == -1 ) {
-        return Board_2ch;
-    } else {
-        return Board_MachiBBS;
-    }
-}
-
-const QPtrList<Thread> Board::getThreadList() const
-{
-    if ( m_boardURL.isEmpty() ) {
+    if ( boardURL.isEmpty() ) {
         kdWarning() << "Waring: board url is empty!" << endl;
         return QPtrList<Thread>();
     }
     QPtrList<Thread> threadList;
 
     KIO::SlaveConfig::self() ->setConfigData( "http",
-            KURL( m_boardURL ).host() ,
+            KURL( boardURL ).host() ,
             "UserAgent",
             QString( "Monazilla/1.00 (Kita/%1)" ).arg( VERSION ) );
     QString tmpFile;
-    if ( KIO::NetAccess::download( subjectTxtURL(), tmpFile ) ) {
+    if ( KIO::NetAccess::download( Kita::boardToSubject( boardURL ), tmpFile ) ) {
         QIODevice * tmpDevice = KFilterDev::deviceForFile( tmpFile, "application/x-gzip" );
         tmpDevice->open( IO_ReadOnly );
 
-        QCp932Codec cp932Codec;
+        if( !m_cp932Codec ) m_cp932Codec = new QCp932Codec();
+        if( !m_eucJpCodec ) m_eucJpCodec = new QEucJpCodec();
         QTextStream stream( tmpDevice );
-        stream.setCodec( &cp932Codec );
+        
+        if ( Kita::boardType( boardURL ) == Board_JBBS ) {
+            stream.setCodec( m_eucJpCodec );
+        } else {
+            stream.setCodec( m_cp932Codec );
+        }
 
         // parse subject.txt(only one format...)
         // FIXME: need to refactoring
         QRegExp regexp;
-        switch ( type() ) {
-        case Board_MachiBBS:
-            regexp.setPattern( "(\\d+\\.cgi),(.*)\\((\\d+)\\)" );
-            break;
+        switch ( Kita::boardType( boardURL ) ) {
         case Board_2ch:
-        default:
             regexp.setPattern( "(\\d+\\.dat)<>(.*)\\((\\d+)\\)" );
             break;
+        case Board_MachiBBS:
+        case Board_JBBS:
+        default:
+            regexp.setPattern( "(\\d+\\.cgi),(.*)\\((\\d+)\\)" );
+            break;
         }
         QString line;
 
@@ -120,9 +95,8 @@ const QPtrList<Thread> Board::getThreadList() const
                 QString subject = regexp.cap( 2 );
                 QString num = regexp.cap( 3 );
 
-                KURL datURL = m_boardURL;
+                KURL datURL = boardURL;
                 datURL.addPath( "/dat/" + fname );
-                Kita::Board::setName( datToBoard( datURL.url() ), name() );
                 Kita::Thread::setName( datURL.url(), subject );
                 Kita::Thread* thread = Kita::Thread::getByURL( datURL.url() );
                 KitaThreadInfo::setResNum( datURL.url(), num.toInt() );
@@ -179,13 +153,13 @@ void Board::setName( const QString& boardURL, const QString& boardName )
 
 const QString& Board::getName( const QString& boardURL )
 {
-    return Board::getByURL( boardURL ) ->name();
+    return Board::getByURL( boardURL ) ->m_boardName;
 }
 
 void Board::replace( const QString& fromURL, const QString& toURL )
 {
     QDictIterator<Kita::Board> it( *m_boardDict );
-    for( ; it.current(); ++it ) {
+    for ( ; it.current(); ++it ) {
         QString url = it.currentKey();
         Kita::Board* board = it.current();
         if ( url.find( fromURL ) == 0 ) {
@@ -198,6 +172,15 @@ void Board::replace( const QString& fromURL, const QString& toURL )
     }
 }
 
+bool Board::isWritingSupported( const KURL& boardURL )
+{
+    if ( Kita::boardType( boardURL.url() ) == Board_2ch ) {
+        return true;
+    } else {
+        return false;
+    }
+}
+
 NullBoard::NullBoard()
 {}
 
