@@ -16,6 +16,7 @@
 #include <qptrlist.h>
 #include <qxml.h>
 #include <qdict.h>
+#include <qeucjpcodec.h>
 
 #include "thread.h"
 
@@ -23,6 +24,8 @@
 @author Hideki Ikemoto
 */
 
+class QCp932Codec;
+
 namespace Kita
 {
     class Thread;
@@ -32,25 +35,23 @@ namespace Kita
         QString m_boardURL;
         QString m_boardName;
         static QDict<Board>* m_boardDict;
+        static QCp932Codec* m_cp932Codec;
+        static QEucJpCodec* m_eucJpCodec;
         Board( const QString& boardURL, const QString boardName = QString::null );
-        int type() const;
-        
+        static Board* getByURL( const QString& boardURL );
     protected:
         Board();
     public:
         ~Board();
-        const KURL subjectTxtURL() const;
-        const QString& url() const;
-        const QString& name() const;
-        const QString id() const;
-        const QPtrList<Thread> getThreadList() const;
-
-        // Factory method
-        static Board* getByURL( const QString& boardURL );
+        static const QString getID( const QString& boardURL );
+        
         static void setName( const QString& boardURL, const QString& boardName );
-        static void replace( const QString& fromURL, const QString& toURL );
-
         static const QString& getName( const QString& boardURL );
+        
+        static const QPtrList<Thread> getThreadList( const QString& boardURL );
+        static void replace( const QString& fromURL, const QString& toURL );
+        
+        static bool isWritingSupported( const KURL& boardURL );
     };
 
     class NullBoard : public Board
@@ -59,6 +60,6 @@ namespace Kita
         NullBoard();
         ~NullBoard();
     };
-};
+}
 
 #endif
