@@ -20,12 +20,7 @@ using namespace Kita;
 
 QString Cache::baseDir( const KURL& url )
 {
-    QString dir;
-    if ( url.protocol() == "k2ch" ) {
-        dir = KGlobal::dirs() ->saveLocation( "cache", "kita" );
-    } else {
-        dir = KProtocolManager::cacheDir();
-    }
+    QString dir = KGlobal::dirs() ->saveLocation( "cache", "kita" );
     if ( dir[ dir.length() - 1 ] != '/' )
         dir += "/";
 
@@ -34,5 +29,7 @@ QString Cache::baseDir( const KURL& url )
 
 QString Cache::getPath( const KURL& url )
 {
-    return baseDir( url ) + Kita::datToCache( url.url() );
+    QString path = Kita::datToCache( url.url() );
+    if ( path == QString::null ) return QString::null;
+    return baseDir( url ) + path;
 }
