@@ -47,9 +47,9 @@ void FavoriteThreads::remove( const QString& datURL )
     m_threadList.remove( datURL );
 }
 
-bool FavoriteThreads::contains( const QString& datURL ) const
+bool FavoriteThreads::contains( const QString& datURL )
 {
-    if ( m_threadList.contains( datURL ) ) {
+    if ( getInstance() ->m_threadList.contains( datURL ) ) {
         return true;
     } else {
         return false;
@@ -134,43 +134,43 @@ bool FavoriteThreads::processBoardNode( QDomNode& node )
 const QString FavoriteThreads::toXML() const
 {
     QDomDocument document;
-    
-//    QDomProcessingInstruction pi = document.createProcessingInstruction( "xml", "version=\"1.0\"" );
-//    document.appendChild( pi );
-    
+
+    //    QDomProcessingInstruction pi = document.createProcessingInstruction( "xml", "version=\"1.0\"" );
+    //    document.appendChild( pi );
+
     QDomElement root = document.createElementNS( "http://kita.sourceforge.jp/ns/favorites", "favorites" );
     document.appendChild( root );
-    
+
     QValueList<QString>::const_iterator it;
-    for( it = threadList().begin(); it != threadList().end(); ++it ) {
+    for ( it = threadList().begin(); it != threadList().end(); ++it ) {
         const Kita::Thread* thread = Kita::Thread::getByURL( *it );
         QDomElement threadElement = document.createElementNS( "http://kita.sourceforge.jp/ns/thread", "thread" );
         root.appendChild( threadElement );
-        
+
         QString datURL = thread->datURL();
         QDomElement datURLElement = document.createElement( "daturl" );
         threadElement.appendChild( datURLElement );
         datURLElement.appendChild( document.createTextNode( datURL ) );
-    
+
         QString threadName = thread->name();
         QDomElement nameElement = document.createElement( "name" );
         threadElement.appendChild( nameElement );
         nameElement.appendChild( document.createTextNode( Kita::unescape( threadName ) ) );
-        
+
         QString resNum = QString::number( thread->resNum() );
         QDomElement resNumElement = document.createElement( "resnum" );
         threadElement.appendChild( resNumElement );
         resNumElement.appendChild( document.createTextNode( resNum ) );
-    
-        // board    
+
+        // board
         QDomElement board = document.createElementNS( "http://kita.sourceforge.jp/ns/board", "board" );
         threadElement.appendChild( board );
-        
+
         QString boardURL = thread->boardURL();
         QDomElement boardURLElement = document.createElement( "url" );
         board.appendChild( boardURLElement );
         boardURLElement.appendChild( document.createTextNode( boardURL ) );
-    
+
         QString boardName = thread->boardName();
         QDomElement boardNameElement = document.createElement( "name" );
         board.appendChild( boardNameElement );
@@ -181,10 +181,10 @@ const QString FavoriteThreads::toXML() const
 
 void FavoriteThreads::replace( QString fromURL, QString toURL )
 {
-    QValueList<QString>& threadList = FavoriteThreads::getInstance()->m_threadList;
+    QValueList<QString>& threadList = FavoriteThreads::getInstance() ->m_threadList;
     QValueList<QString>::iterator it;
     for ( it = threadList.begin(); it != threadList.end(); ++it ) {
-        QString url = (*it);
+        QString url = ( *it );
         if ( url.find( fromURL ) == 0 ) {
             url = url.replace( 0, fromURL.length(), toURL );
             threadList.remove( it );
