@@ -15,6 +15,11 @@
 
 namespace Kita
 {
+    enum {
+        Board_MachiBBS,
+        Board_JBBS,
+        Board_2ch
+    };
 
     /**
      * @author Hideki Ikemoto
@@ -28,6 +33,8 @@ namespace Kita
     QString datToCache( const QString& datURL );
     QString httpToK2ch( const QString& httpURL );
     QString unescape( const QString& str );
-};
+    int boardType( const QString& url );
+    uint datToSince( const QString& datURL );
+}
 
 #endif
