@@ -84,8 +84,7 @@ void Thread::setResNum( int resNum )
 
 const QString& Thread::boardName() const
 {
-    Board * board = Board::getByURL( boardURL() );
-    return board->name();
+    return Kita::Board::getName( boardURL() );
 }
 
 const QString Thread::boardURL() const
@@ -104,9 +103,8 @@ Thread* Thread::getByURL( const QString& datURL )
         m_threadDict = new QDict<Thread>();
     }
 
-    if ( m_threadDict->find( datURL ) ) {
-        return m_threadDict->find( datURL );
-    }
+    Thread* thread = m_threadDict->find( datURL );
+    if ( thread ) return thread;
 
     Thread* newThread = new Thread( datURL );
     m_threadDict->insert( datURL, newThread );
@@ -114,6 +112,14 @@ Thread* Thread::getByURL( const QString& datURL )
     return newThread;
 }
 
+/* static & public */
+Thread* Thread::getByURLNew( const KURL& datURL )
+{
+    if ( m_threadDict == NULL ) return NULL;
+    if ( datURL.isEmpty() ) return NULL;
+    return m_threadDict->find( datURL.prettyURL() );
+}
+
 void Thread::setName( const QString& datURL, const QString& threadName )
 {
     if ( datURL.isNull() ) {
