@@ -20,7 +20,7 @@
 namespace KIO
 {
     class Job;
-};
+}
 
 class KURL;
 
@@ -29,9 +29,6 @@ namespace Kita
     /**
     @author Hideki Ikemoto
     */
-    class Board;
-    class BoardXmlParser;
-
     class Thread
     {
         Thread( const QString& datURL, const QString& threadName = QString::null );
@@ -53,6 +50,7 @@ namespace Kita
         const QString boardID() const;
 
         static Thread* getByURL( const QString& datURL );
+	static Thread* getByURLNew( const KURL& datURL );
         static void setName( const QString& datURL, const QString& threadName );
         static void replace( const QString& fromURL, const QString& toURL );
     private:
@@ -67,6 +65,6 @@ namespace Kita
         NullThread();
         ~NullThread();
     };
-};
+}
 
 #endif
