@@ -18,6 +18,8 @@
 #include <kcmdlineargs.h>
 #include <klocale.h>
 
+#include "libkita/kitaconfig.h"
+
 static const char *description =
     I18N_NOOP("Kita - 2ch client for KDE");
 
@@ -36,6 +38,8 @@ int main(int argc, char **argv)
                      KAboutData::License_GPL, "(C) 2003-2004 Kita Developers", 0, 0, "ikemo@users.sourceforge.jp");
     about.addAuthor( "Hideki Ikemoto", I18N_NOOP("maintainer, initial code"), "ikemo@users.sourceforge.jp" );
     about.addAuthor( "konqueror plugin no hito", I18N_NOOP("konqueror plugin, KDE part"), "ogirin@users.sourceforge.jp");
+    about.addAuthor( "421", I18N_NOOP("kitanavi, threadview's improvement") );
+    about.addAuthor( "Toshihiko Okada", I18N_NOOP("improvements"), "tossi@users.sourceforge.jp");
     KCmdLineArgs::init(argc, argv, &about);
     KCmdLineArgs::addCmdLineOptions(options);
     KUniqueApplication app;
