@@ -16,11 +16,9 @@
 #include <kparts/browserextension.h>
 #include <dom/html_base.h>
 
-#include <qtextbrowser.h>
+#include <ktextbrowser.h>
 
 #include "kita2ch.h"
-#include "libkita/thread.h"
-#include "kitadomtree.h"
 
 class KURL;
 class KitaHTMLPart;
@@ -31,22 +29,19 @@ template <class T> class QValueStack;
 
 namespace Kita
 {
-    class Access;
-    class PopupTextBrowser;
-    class ResPopup;
-};
+    class KitaSubjectLabel;
+}
 
 /* mode , m_viewmode uses them. */
 enum{
     VIEWMODE_PARENT,
-    VIEWMODE_KITANAVI,
-    VIEWMODE_PREVIEW
+    VIEWMODE_KITANAVI
 };
 
 namespace KIO
 {
     class Job;
-};
+}
 
 /**
  *
@@ -62,97 +57,73 @@ public:
     ~KitaThreadView();
     const QString threadName() const;
     const KURL threadURL() const;
-    void searchNext( const QStringList& input );
-    void killJob();
-    void focusSearchCombo();
 
-    void setupEx( const Kita::Thread* thread,
-                  Kita::Access* access,
-                  KitaThreadView* viewparent,
-                  KitaDomTree* domtreeparent,
-                  int mode );
+    void setup( const KURL& datURL, int mode );    
     void showStatusBar( QString info );
-    void gotoAnchor( QString anc );
-    Kita::Thread* get2chThread() { return m_thread; }
     int getViewMode() { return m_viewmode; }
 
-    /* !! static !! */
-    static KURL filterReadCGICore( const KURL&, Kita::Thread* thread );
-    static void getRefNumber( const KURL& url, Kita::Thread* thread,
-                              int& renNum, int& refNum2 );
 
-    /* for preview and KitaNavi */    
-    void domAppendData(QString& str,int bufnum,int num );
-    void domDeleteRes(int bufnum);
-    void domAppendBelt(QString idstr);
-    void domAppendHTML(QString& url,QString& html);
-    void domApplyChange(QString lbstr,QString hstr,QString fstr,QString anchor,QString cmbstr);
-    
+    /* for preview and KitaNavi */
+    void domAppendData( QString& str, int bufnum, int num );
+    void domDeleteRes( int bufnum );
+    void domAppendBelt( QString idstr );
+    void domSetInnerHTML(const QString& html );
+    void domApplyChange( QString lbstr, QString hstr, QString fstr, QString anchor, QString cmbstr );
+
 public slots:
-    void showThread( const Kita::Thread* thread );
+    void subjectlinkClicked(const QString& URL );
+    void subjectlinkMClicked( const QString &URL );
+    void showThread( const KURL& datURL, int num );
     void setFont( const QFont& font );
     void slotReloadButton();
-    void slotOpenURLRequest( const KURL&, const KParts::URLArgs& );
-
+    void slotStopLoading();        
+    void focusSearchCombo();
+    void slotDeleteButtonClicked();    
+    void slotSearchNext();
+    void slotSearchPrev();
+    void slotGobackAnchor();
+    void slotGotoHeader();
+    void slotGotoFooter();
+    
 protected slots:
     void slotDOMNodeActivated( const DOM::Node& node );
     void slotPopupMenu( KXMLGUIClient*, const QPoint&, const KURL&, const QString&, mode_t );
 
-private:       // Private attributes
-    Kita::Access* m_access;
-    Kita::Thread* m_thread;
+private:        // Private attributes
+    int m_serverTime;
+    KURL m_datURL;
     KitaHTMLPart* m_threadPart;
     Kita::PostInfo m_postInfo;
-    Kita::ResPopup* m_popup;
+    Kita::KitaSubjectLabel* subjectLabel;
 
-    KitaDomTree* m_domtree;
     bool m_revsearch;
     int m_viewmode;
     int m_rescode;
 
     /* for config */
-    int m_preShowNum;
-    int m_afterShowNum;
     QString m_mailaddr;
-    int m_maxpopup;
-    QString m_style;
-    bool m_online;
-
-    /* for KitaNavi */
-    KitaDomTree* m_domtreeparent;
-    KitaThreadView* m_viewparent;
-
-    void update_readCache();
-    void update_rendering( bool breload );
-    void update_finish();
-    void update_copydata( const QString& linedata, int basenum );
 
     void appendRes( int startnum, int endnum );
-    void showPopup( QString innerHTML, QString imgfile );
-    void slotWriteButtonClickedCore( QString resstr );
 
     void insertSearchCombo();
-    KURL filterReadCGI( const KURL& );
-    void setSubjectLabel( const QString& boardName, const QString& threadName );
+    void setSubjectLabel( const QString& boardName, const QString& threadName, const QString boardURL );
     KitaWriteDialog* openDialog( const Kita::PostInfo& info );
-    const QString footer() const;
     QStringList parseSearchQuery( const QString& input ) const;
     void updateButton();
 
+
 private slots:
     void slotSearchButton();
-    void slotHighLightenButton( bool yes );
-    void slotOnURL( const QString& url );
     void slotPostStarted( KIO::Job*, const Kita::PostInfo& );
     void slotBookmarkButtonClicked( bool on );
-    void slotWriteButtonClicked();
+    void slotWriteButtonClicked( QString resstr = QString::null );
     void slotShowErrorDialog( const QString& input, const KURL& urlOfInput = 0 );
-    void hidePopup();
+    void slotComboActivated( int index );
+    void slotUpdateInfo();
+    void slotSearchPrivate( bool rev );    
 
 signals:
-    void showThreadCompleted( const KURL& threadUrl );
     void datURLRedirected( const KURL& newDatURL );
-    void signalChangeStatusbar( const QString& );
     void postResponse( const QString& response, const KURL& bbscgi = KURL() );
     //re-impl signals of KParts::Browserextension of KHTMLPart
     void openURLRequest( const KURL& url, const KParts::URLArgs& args = KParts::URLArgs() );
@@ -160,30 +131,45 @@ signals:
     void setLocationBarURL( const QString& url );
     void enableAction( const char* name, bool enabled );
     void popupMenu( KXMLGUIClient*, const QPoint&, const KURL&, const QString&, mode_t );
-    void thread( const Kita::Thread* );
-    void writeSucceeded();
-    void bookmarked( const Kita::Thread*, bool on );
+    void updateSubjectTab( const KURL& datURL );
+    void updateThreadTab( const KURL& datURL );
+    void setMainURLLine( const KURL& url );
+    void setMainCaption( const QString& captionStr );
+    void setMainStatusbar( const QString& statusStr );
+    void bookmarked( const QString& datURL, bool on );
+    void openBoardRequested( const QString& URL, bool useTab );
+    void showThreadCompleted(); /* to KitaThreadPart */
+    void closeThreadTab( const KURL& url );
 };
 
 namespace Kita
 {
-    class PopupTextBrowser : public QTextBrowser
+    // reimplement KActiveLabel based KTextBrowser
+    class KitaSubjectLabel : public KTextBrowser
     {
+
+    Q_OBJECT
+
     public:
-        PopupTextBrowser( QFrame* frame );
-        ~PopupTextBrowser();
+        KitaSubjectLabel( QWidget *parent, const char * name = 0 );
+
+        QSize minimumSizeHint() const;
+        QSize sizeHint() const;
+    private slots:
+        void paletteChanged();
+        void popupOpenAsNewTab();
+        void popupCopyToClipboard();
+        void popupFavorites();
+    protected:
+        virtual QPopupMenu * createPopupMenu ( const QPoint & pos );
+        virtual void contentsMousePressEvent ( QMouseEvent * e );
+        virtual void contentsMouseReleaseEvent ( QMouseEvent * e );
+    signals:
+        void urlMClick( const QString& url );
+    private:
+        QString m_popupURL;
     };
 
-    class ResPopup : public QFrame
-    {
-        KHTMLPart* m_part;
-        Kita::PopupTextBrowser* m_browser;
-    public:
-        ResPopup( KHTMLView* view );
-        ~ResPopup();
-        void setText( QString& str );
-        void adjustSize();
-    };
 }
 
 #endif
