@@ -10,9 +10,13 @@
 
 #include "kitawritedialog.h"
 #include "libkita/qcp932codec.h"
-#include "libkita/thread.h"
-#include "kitaconfig.h"
+#include "libkita/kitaconfig.h"
 #include "kita2ch.h"
+#include "kitahtmlpart.h"
+#include "kitahtmlview.h"
+#include "libkita/datmanager.h"
+#include "libkita/parsemisc.h"
+#include "libkita/signalcollection.h"
 
 #include <ksqueezedtextlabel.h>
 #include <klocale.h>
@@ -20,6 +24,7 @@
 #include <kstandarddirs.h>
 #include <klineedit.h>
 
+#include <qapplication.h>
 #include <qtextedit.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
@@ -27,13 +32,15 @@
 #include <qeucjpcodec.h>
 #include <qfile.h>
 #include <qmessagebox.h>
+#include <qtabwidget.h>
+#include <qcheckbox.h>
 
 #include <kio/job.h>
 
 KitaWriteDialogPrivate* KitaWriteDialog::s_private = 0;
 
-KitaWriteDialog::KitaWriteDialog( QWidget* parent, const char* name )
-        : KitaWriteDialogBase( parent, name )
+KitaWriteDialog::KitaWriteDialog( const KURL& datURL, QWidget* parent, const char* name )
+        : KitaWriteDialogBase( parent, name, WStyle_Customize |  WType_TopLevel | WStyle_DialogBorder | WStyle_Title | WStyle_SysMenu | WStyle_MinMax | Qt::WDestructiveClose )
 {
     QFont font = KitaConfig::font();
     bodyText->setFont( font );
@@ -46,9 +53,42 @@ KitaWriteDialog::KitaWriteDialog( QWidget* parent, const char* name )
     faceCombo->insertItem( "" );
     QStringList list = KitaConfig::asciiArtList();
     QStringList::iterator it;
-    for ( it = list.begin(); it != list.end(); ++it ) {
+    for ( it = list.begin(); it != list.end(); ++it )
+    {
         faceCombo->insertItem( *it );
     }
+
+    /* emit when this widget is deactivated */
+    connect( this, SIGNAL( windowDeactivated() ),
+             Kita::SignalCollection::getInstance(), SIGNAL( windowDeactivated() ));
+
+    /* If this widget is active and receives
+       signal isKitaActive, then emit signal kitaIsActive. */
+    connect( Kita::SignalCollection::getInstance(), SIGNAL( isKitaActive() ),
+             this, SLOT( slotIsKitaActive() ) );
+
+    connect( this, SIGNAL( kitaIsActive() ),
+             Kita::SignalCollection::getInstance(), SIGNAL( kitaIsActive() ) );
+
+    connect( faceCombo, SIGNAL( activated( const QString& ) ),
+             bodyText, SLOT( insert( const QString& ) ) );
+    /*--------------------*/
+    /* init preview       */
+
+    m_datURL = datURL;
+
+    connect( qtw, SIGNAL( currentChanged ( QWidget * ) ),
+             this, SLOT( slotCurrentChanged ( QWidget * ) ) );
+
+    m_preview = new KitaHTMLPart( NULL );
+    qtw->addTab( m_preview->view(), i18n( "preview" ) );
+
+    m_preview->setup( HTMLPART_MODE_KHTML, m_datURL );
+
+    /* move to center */
+    QWidget * desk = QApplication::desktop();
+    QPoint p = QPoint( (desk->width() - width() )/2, (desk->height()-height())/2 );
+    move(p);
 }
 
 KitaWriteDialog::~KitaWriteDialog()
@@ -78,15 +118,17 @@ void KitaWriteDialog::fetchPostInfo( Kita::PostInfo* storage ) const
 
 // TODO: Thread饹Ȥ褦˽񤭴
 KitaWriteDialog* KitaWriteDialog::open( const Kita::PostInfo& info,
-                                        const Kita::Thread* thread )
+                                        const KURL& datURL,
+                                        QWidget* parent )
 {
     if ( ! info.check() ) return 0;
-    if ( ! s_private ) {
+    if ( ! s_private )
+    {
         s_private = new KitaWriteDialogPrivate;
         if ( ! s_private ) return 0;
     }
 
-    KitaWriteDialog* new_dlg = new KitaWriteDialog;
+    KitaWriteDialog* new_dlg = new KitaWriteDialog( datURL, parent );
     if ( ! new_dlg ) return 0;
 
     new_dlg->m_postInfo = info;
@@ -95,19 +137,27 @@ KitaWriteDialog* KitaWriteDialog::open( const Kita::PostInfo& info,
     new_dlg->connect( new_dlg->buttonOk, SIGNAL( clicked() ),
                       new_dlg, SLOT( postMessage() ) );
 
+    new_dlg->connect( new_dlg->buttonCancel, SIGNAL( clicked() ),
+                      new_dlg, SLOT( reject() ) );
+
     // set fields
     new_dlg->nameLine->setText( info.name );
     new_dlg->mailLine->setText( info.mail );
+    if ( info.mail == "sage" )
+    {
+        new_dlg->sageBox->setChecked( true );
+        new_dlg->m_mailswap = "";
+    }
     new_dlg->bodyText->setText( info.body );
 
-    new_dlg->boardNameLabel->setText( thread->boardName() );
-    new_dlg->threadNameLabel->setText( thread->name() );
-    new_dlg->threadURLLabel->setText( thread->url() );
+    new_dlg->boardNameLabel->setText( Kita::DatManager::thread_boardName( datURL ) );
+    new_dlg->threadNameLabel->setText( Kita::DatManager::thread_name( datURL ) );
+    new_dlg->threadURLLabel->setText( Kita::DatManager::thread_url( datURL ) );
 
     KCompletion* comp = KitaConfig::nameCompletion();
     new_dlg->nameLine->setCompletionObject( comp );
 
-    new_dlg->setCaption( i18n( "Write in %1" ).arg( thread->name() ) );
+    new_dlg->setCaption( i18n( "Write in %1" ).arg( Kita::DatManager::thread_name( datURL ) ) );
     return new_dlg;
 }
 
@@ -120,7 +170,8 @@ static void logPostMessage( const Kita::PostInfo& postInfo,
     QString logPath = locateLocal( "appdata", "log.txt" );
 
     QFile file( logPath );
-    if ( file.open( IO_WriteOnly | IO_Append ) ) {
+    if ( file.open( IO_WriteOnly | IO_Append ) )
+    {
         QTextStream stream( &file );
         stream.setEncoding( QTextStream::UnicodeUTF8 );
 
@@ -196,7 +247,7 @@ void KitaWriteDialog::slotPostFinished( KIO::Job* job )
 
     int idx = s_private->m_heaplist.find( this );
     if ( idx != -1 )
-        delete this;
+        close( TRUE );
 }
 
 void KitaWriteDialog::reject()
@@ -204,9 +255,10 @@ void KitaWriteDialog::reject()
     switch ( QMessageBox::warning( this, "Kita",
                                    i18n( "If you close this dialog, you will lose text.\n"
                                          "Do you want to close?" ),
-                                   QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default ) ) {
+                                   QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default ) )
+    {
     case QMessageBox::Ok:
-        KitaWriteDialogBase::reject();
+        close( TRUE );
         break;
     case QMessageBox::Cancel:
         // do nothing
@@ -216,63 +268,36 @@ void KitaWriteDialog::reject()
 
 // vim:sw=2:
 
-/*------------------------------------------------------------------*/
-/*------------------------------------------------------------------*/
-
-/* SHOBON extension for preview */
-
-#include <qtabwidget.h>
-#include "kitathreadview.h"
-#include "kitadomtree.h"
-#include "libkita/access.h"
-
-
-void KitaWriteDialog::setupEx(
-    Kita::Thread* thread,
-    Kita::Access* access,
-    KitaThreadView* viewparent,
-    KitaDomTree* domtreeparent,
-    int num
-)
-{
-
-    int wd = width() + 100;
-    int ht = height() + 100;
-    resize( wd, ht );
-
-    connect( qtw, SIGNAL( currentChanged ( QWidget * ) ),
-             this, SLOT( slotCurrentChanged ( QWidget * ) ) );
-
-    m_preview = new KitaThreadView( qtw );
-    qtw->addTab( m_preview, "preview" );
-
-    m_preview->setupEx( thread , access, viewparent, domtreeparent,
-                        VIEWMODE_PREVIEW );
-
-    m_bufnum = 0;
-    m_resnum = num;
-}
-
-
-/*-------------------------------------------------*/
 
+/* update preview screen */
 void KitaWriteDialog::slotCurrentChanged ( QWidget * w )
 {
     if ( w == bodyText ) return ;
 
-    m_preview->domDeleteRes( m_bufnum );
-    m_bufnum++;
+    int resnum = Kita::DatManager::getReadNum( m_datURL ) + 1 ;
 
     QDateTime now = QDateTime::currentDateTime();
     QString bodystr = body();
-    bodystr.replace( ">", "&gt;" ).replace( "\n", " <br> " );
+    bodystr.replace( "<", "&lt;" ).replace( ">", "&gt;" ).replace( "\n", " <br> " );
     QString namestr = name();
     if ( namestr == NULL || namestr.length() == 0 ) namestr = "(default name)";
-    QString str = namestr + "<>" + mail() + "<>"
-                  + now.toString( "yy/MM/dd hh:mm" )
-                  + "<> " + bodystr + " <>";
+    QString rawData = namestr + "<>" + mail() + "<>"
+                      + now.toString( "yy/MM/dd hh:mm" )
+                      + "<> " + bodystr + " <>";
 
-    m_preview->domAppendData( str, m_bufnum, m_resnum );
-    m_preview->domApplyChange( QString::null,
-                               QString::null, QString::null, QString::null, QString::null );
+    QString htmlstr = Kita::ParseMisc::DatToHtml(rawData,resnum,KitaConfig::showMailAddress());
+    m_preview->setInnerHTML( htmlstr );
+}
+
+
+/* when window is deactivated, emit signal to popup */ /* protected */
+void KitaWriteDialog::windowActivationChange ( bool  )
+{
+    if(!isActiveWindow()) emit windowDeactivated();
+}
+
+/* private slot */
+void KitaWriteDialog::slotIsKitaActive()
+{
+    if(isActiveWindow()) emit kitaIsActive();
 }
