@@ -19,13 +19,12 @@
 template <class type> class QPtrList;
 class KitaWriteDialogPrivate;
 class KitaWriteDialog;
-class KitaThreadView;
-class KitaDomTree;
+class KitaHTMLPart;
+
 namespace Kita
 {
     class Access;
-    class Thread;
-};
+}
 
 /**
  * 
@@ -35,7 +34,7 @@ class KitaWriteDialog : public KitaWriteDialogBase
 {
     Q_OBJECT
 public:
-    KitaWriteDialog( QWidget* parent = 0, const char* name = 0 );
+    KitaWriteDialog( const KURL& datURL, QWidget* parent = 0, const char* name = 0 );
     virtual ~KitaWriteDialog();
     const QString name() const;
     const QString mail() const;
@@ -43,14 +42,7 @@ public:
 
     virtual bool error() { return false; };
 
-    static KitaWriteDialog* open( const Kita::PostInfo& info, const Kita::Thread* thread );
-    void setupEx(
-        Kita::Thread* thread,
-        Kita::Access* access,
-        KitaThreadView* viewparent,
-        KitaDomTree* domtreeparent,
-        int num
-    );
+    static KitaWriteDialog* open( const Kita::PostInfo& info, const KURL& datURL, QWidget* parent );
 
 public slots:
     void postMessage();
@@ -65,6 +57,7 @@ signals:
 
 protected:
     Kita::PostInfo m_postInfo;
+    void windowActivationChange( bool );
 
 protected slots:
     virtual void reject();
@@ -75,13 +68,19 @@ private:
     QCString m_array;
     bool m_error;
     static KitaWriteDialogPrivate* s_private;
-    KitaThreadView *m_preview;
-    int m_bufnum;
+    KitaHTMLPart *m_preview;
     int m_resnum;
+    KURL m_datURL;
 
 private slots:
     void slotRecieveData( KIO::Job*, const QByteArray& );
     void slotPostFinished( KIO::Job* );
+    void slotIsKitaActive();    
+
+signals:
+    void windowDeactivated();
+    void isKitaActive();
+    void kitaIsActive();          
 
 };
 
