@@ -32,7 +32,8 @@ namespace Kita
 {
     class AsciiArtPrefPage;
     class UIPrefPage;
-};
+    class AbonePrefPage;
+}
 
 class KitaPreferences : public KDialogBase
 {
@@ -41,24 +42,34 @@ class KitaPreferences : public KDialogBase
 public:
     KitaPreferences();
 
+protected:
+    virtual void slotApply();
+
 private:
     KitaFontPrefPage* m_fontPage;
     KitaColorPrefPage* m_colorPage;
     Kita::AsciiArtPrefPage* m_asciiArtPage;
     Kita::UIPrefPage* m_uiPage;
+    Kita::AbonePrefPage* m_abonePage;
     DebugPrefPage* m_debugPage;
 
+private slots:
+    void slotChanged();
+    virtual void slotOk();
+
 signals:
     void fontChanged( const QFont& );
-    void threadFontChanged( const QFont& );
 };
 
 class KitaFontPrefPage : public KitaFontPrefBase
 {
     Q_OBJECT
 
+    bool m_threadFontchanged;
+
 public:
     KitaFontPrefPage( QWidget* parent = 0 );
+    void apply();
 
 public slots:
     void slotFontButtonClicked();
@@ -69,7 +80,8 @@ private:
 
 signals:
     void fontChanged( const QFont& );
-    void threadFontChanged( const QFont& );
+    void setFontOfHTMLPart();
+    void changed();
 };
 
 class KitaColorPrefPage : public KitaColorPrefBase
@@ -78,9 +90,10 @@ class KitaColorPrefPage : public KitaColorPrefBase
 
 public:
     KitaColorPrefPage( QWidget* parent = 0 );
+    void apply();
 
-public slots:
-    void slotChangeButtonClicked();
+signals:
+    void changed();
 };
 
 class DebugPrefPage : public DebugPrefBase
@@ -103,6 +116,9 @@ namespace Kita
         AsciiArtPrefPage( QWidget* parent = 0 );
     public slots:
         void commit();
+
+    signals:
+        void changed();
     };
 
     class UIPrefPage : public UIPrefBase
@@ -110,9 +126,11 @@ namespace Kita
         Q_OBJECT
     public:
         UIPrefPage( QWidget* parent = 0 );
-    private slots:
-        void slotUseTabToggled( bool on );
+        void apply();
+
+    signals:
+        void changed();
     };
-};
+}
 
 #endif // _KITAPREF_H_
