@@ -13,12 +13,17 @@
 #include <kiconloader.h>
 #include <klistview.h>
 #include <klocale.h>
+#include <kurl.h>
 
 #include <qtoolbutton.h>
 #include <qcombobox.h>
 #include <qregexp.h>
 #include <qheader.h>
 
+#include "libkita/thread.h"
+#include "libkita/kitaconfig.h"
+#include "libkita/signalcollection.h"
+
 using namespace Kita;
 
 ThreadListView::ThreadListView( QWidget* parent, const char* name )
@@ -37,7 +42,12 @@ ThreadListView::ThreadListView( QWidget* parent, const char* name )
     subjectList->addColumn( i18n( "Unread" ) );
     subjectList->addColumn( i18n( "Since" ) );
 
-    subjectList->setColumnWidth( Col_Subject, 400 );
+    QHeader *h = subjectList->header();
+    h->setResizeEnabled( FALSE, Col_Mark );
+    h->setResizeEnabled( FALSE, Col_Icon );
+    h->setStretchEnabled( TRUE, Col_Subject );
+
+    //subjectList->setColumnWidth( Col_Subject, 400 );
     subjectList->setColumnWidthMode( Col_Subject, QListView::Manual );
 
     connect( SearchButton, SIGNAL( clicked() ),
@@ -46,6 +56,10 @@ ThreadListView::ThreadListView( QWidget* parent, const char* name )
              SLOT( slotSearchButton() ) );
     connect( HideButton, SIGNAL( toggled( bool ) ),
              SLOT( slotHideButton( bool ) ) );
+    connect( subjectList, SIGNAL( mouseButtonClicked( int, QListViewItem*, const QPoint&, int ) ),
+             SLOT( slotMouseButtonClicked( int, QListViewItem* ) ) );
+    connect( this, SIGNAL( bookmarked( const QString&, bool ) ),
+             Kita::SignalCollection::getInstance(), SIGNAL( bookmarked( const QString&, bool ) ) );
 }
 
 ThreadListView::~ThreadListView()
@@ -141,6 +155,28 @@ void ThreadListView::slotHideButton( bool on )
     }
 }
 
+void ThreadListView::slotMouseButtonClicked( int button, QListViewItem* item )
+{
+    if ( ! item ) return ;
+
+    KURL datURL = item->text( Col_DatURL );
+
+    Kita::Thread* thread = Kita::Thread::getByURL( datURL.url() );
+
+    switch ( button ) {
+    case MidButton:
+        emit showThreadRequested( thread->datURL(), true );
+        break;
+    case LeftButton:
+        if ( KitaConfig::alwaysUseTab() ) {
+            emit showThreadRequested( thread->datURL(), true );
+        } else {
+            emit showThreadRequested( thread->datURL(), false );
+        }
+        break;
+    }
+}
+
 int ThreadListViewItem::compare( QListViewItem* i, int col, bool ascending ) const
 {
     switch ( col ) {
@@ -150,6 +186,8 @@ int ThreadListViewItem::compare( QListViewItem* i, int col, bool ascending ) con
         return QString::localeAwareCompare( i->key( col, ascending ), key( col, ascending ) );
     case Col_Mark:
         return QString::localeAwareCompare( i->key( Col_MarkOrder, ascending ), key( Col_MarkOrder, ascending ) );
+    case Col_Since:
+        return QString::localeAwareCompare( i->key( col, ascending ), key( col, ascending ) );
     default:
         return QString::localeAwareCompare( key( col, ascending ), i->key( col, ascending ) );
     }
